package EntityReplacer;

use 5.010000;
use strict;
use warnings;

require Exporter;

our @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use EntityReplacer ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw(
	
) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(
	
);

our $VERSION = '0.10';

# Set of allowable XML entities
our %allow	= map { $_ => 1 } qw(&lt; &gt; &amp; &apos; &quot;);

# Map the numeric entities to their character entities
# for the ALLOWable character entities
our %numeric	= (
    # hex forms
    '&#x3c;'	=>	'&lt;',
    '&#x3e;'	=>	'&gt;',
    '&#x26;'	=>	'&amp;',
    '&#x27;'	=>	'&apos;',
    '&#x22;'	=>	'&quot;',
    # decimal forms
    '&#60;'	=>	'&lt;',
    '&#62;'	=>	'&gt;',
    '&#38;'	=>	'&amp;',
    '&#39;'	=>	'&apos;',
    '&#34;'	=>	'&quot;',
);

# The following hash has mappings for character entity references to UTF-8
# ISOAMSA ISOAMSB ISOAMSC ISOAMSN ISOAMSO ISOAMSR ISOCYR1 ISOCYR2
# ISOGRK1 ISOGRK2 ISOGRK3 ISOGRK4 ISOLAT1 ISOLAT2 ISOMFRK ISONUM
# ISOPUB ISOTECH MMLALIAS MMLEXTRA

# Note: these are alphabetized even though they can be in any order.

# It might be nice to allow these to be separately defined and brought in as needed.

our %entities	= (
    '&AElig;'			=>	"\x{00C6}",
    '&Aacgr;'			=>	"\x{0386}",
    '&Aacugr;'			=>	"\x{1FBB}",
    '&Aacute;'			=>	"\x{00C1}",
    '&Abar;'			=>	"\x{0100}",
    '&Abreve;'			=>	"\x{0102}",
    '&Acirc;'			=>	"\x{00C2}",
    '&Acirgr;'			=>	"\x{0391}\x{1FC0}",
    '&Acy;'			=>	"\x{0410}",
    '&Adot;'			=>	"\x{1EA0}",
    '&Agr;'			=>	"\x{0391}",
    '&Agr;'			=>	"\x{0391}",
    '&Agragr;'			=>	"\x{1FBA}",
    '&Agrave;'			=>	"\x{00C0}",
    '&Amacr;'			=>	"\x{0100}",
    '&And;'			=>	"\x{2A53}",
    '&Aogon;'			=>	"\x{0104}",
    '&ApplyFunction;'		=>	"\x{2061}",
    '&Aragr;'			=>	"\x{1F0C}",
    '&Arggr;'			=>	"\x{1F0B}",
    '&Aring;'			=>	"\x{00C5}",
    '&Arougr;'			=>	"\x{1F09}",
    '&Asagr;'			=>	"\x{1F0C}",
    '&Ascgr;'			=>	"\x{1F0E}",
    '&Asggr;'			=>	"\x{1F0A}",
    '&Ashort;'			=>	"\x{102}",
    '&Asmogr;'			=>	"\x{1F08}",
    '&Assign;'			=>	"\x{2254}",
    '&Atilde;'			=>	"\x{00C3}",
    '&Auml;'			=>	"\x{00C4}",
    '&Backslash;'		=>	"\x{2216}",
    '&Barv;'			=>	"\x{2AE7}",
    '&Barwed;'			=>	"\x{2306}",
    '&Bcy;'			=>	"\x{0411}",
    '&Because;'			=>	"\x{2235}",
    '&Bernoullis;'		=>	"\x{212C}",
    '&Bgr;'			=>	"\x{0392}",
    '&Bgr;'			=>	"\x{0392}",
    '&Breve;'			=>	"\x{02D8}",
    '&Bumpeq;'			=>	"\x{224E}",
    '&CHcy;'			=>	"\x{0427}",
    '&Cacute;'			=>	"\x{0106}",
    '&Cap;'			=>	"\x{22D2}",
    '&CapitalDifferentialD;'	=>	"\x{2145}",
    '&Cayleys;'			=>	"\x{212D}",
    '&Ccaron;'			=>	"\x{010C}",
    '&Ccedil;'			=>	"\x{00C7}",
    '&Ccirc;'			=>	"\x{0108}",
    '&Cconint;'			=>	"\x{2230}",
    '&Cdot;'			=>	"\x{010A}",
    '&Cedilla;'			=>	"\x{00B8}",
    '&CenterDot;'		=>	"\x{00B7}",
    '&Cfr;'			=>	"\x{212D}",
    '&CircleDot;'		=>	"\x{2299}",
    '&CircleMinus;'		=>	"\x{2296}",
    '&CirclePlus;'		=>	"\x{2295}",
    '&CircleTimes;'		=>	"\x{2297}",
    '&ClockwiseContourIntegral;'	=>	"\x{2232}",
    '&CloseCurlyDoubleQuote;'	=>	"\x{201D}",
    '&CloseCurlyQuote;'		=>	"\x{2019}",
    '&Colon;'			=>	"\x{2237}",
    '&Colone;'			=>	"\x{2A74}",
    '&Congruent;'		=>	"\x{2261}",
    '&Conint;'			=>	"\x{222F}",
    '&ContourIntegral;'		=>	"\x{222E}",
    '&Coproduct;'		=>	"\x{2210}",
    '&CounterClockwiseContourIntegral;'	=>	"\x{2233}",
    '&Cross;'			=>	"\x{2A2F}",
    '&Cup;'			=>	"\x{22D3}",
    '&CupCap;'			=>	"\x{224D}",
    '&DD;'			=>	"\x{2145}",
    '&DDotrahd;'		=>	"\x{2911}",
    '&DIGgr;'			=>	"\x{03DC}",
    '&DJcy;'			=>	"\x{0402}",
    '&DScy;'			=>	"\x{0405}",
    '&DZcy;'			=>	"\x{040F}",
    '&Dagger;'			=>	"\x{2021}",
    '&Dagger;'			=>	"\x{2021}",
    '&Darr;'			=>	"\x{21A1}",
    '&Dashv;'			=>	"\x{2AE4}",
    '&Dcaron;'			=>	"\x{010E}",
    '&Dcy;'			=>	"\x{0414}",
    '&Del;'			=>	"\x{2207}",
    '&Delta;'			=>	"\x{0394}",
    '&Dgr;'			=>	"\x{0394}",
    '&Dgr;'			=>	"\x{0394}",
    '&DiacriticalAcute;'	=>	"\x{00B4}",
    '&DiacriticalDot;'		=>	"\x{02D9}",
    '&DiacriticalDoubleAcute;'	=>	"\x{02DD}",
    '&DiacriticalGrave;'	=>	"\x{0060}",
    '&DiacriticalTilde;'	=>	"\x{02DC}",
    '&Diamond;'			=>	"\x{22C4}",
    '&DifferentialD;'		=>	"\x{2146}",
    '&Dot;'			=>	"\x{00A8}",
    '&DotDot;'			=>	"\x{20DC}",
    '&DotEqual;'		=>	"\x{2250}",
    '&DoubleContourIntegral;'	=>	"\x{222F}",
    '&DoubleDot;'		=>	"\x{00A8}",
    '&DoubleDownArrow;'		=>	"\x{21D3}",
    '&DoubleLeftArrow;'		=>	"\x{21D0}",
    '&DoubleLeftRightArrow;'	=>	"\x{21D4}",
    '&DoubleLeftTee;'		=>	"\x{2AE4}",
    '&DoubleLongLeftArrow;'	=>	"\x{27F8}",
    '&DoubleLongLeftRightArrow;'	=>	"\x{27FA}",
    '&DoubleLongRightArrow;'	=>	"\x{27F9}",
    '&DoubleRightArrow;'	=>	"\x{21D2}",
    '&DoubleRightTee;'		=>	"\x{22A8}",
    '&DoubleUpArrow;'		=>	"\x{21D1}",
    '&DoubleUpDownArrow;'	=>	"\x{21D5}",
    '&DoubleVerticalBar;'	=>	"\x{2225}",
    '&DownArrow;'		=>	"\x{2193}",
    '&DownArrowBar;'		=>	"\x{2913}",
    '&DownArrowUpArrow;'	=>	"\x{21F5}",
    '&DownBreve;'		=>	"\x{0311}",
    '&DownLeftRightVector;'	=>	"\x{2950}",
    '&DownLeftTeeVector;'	=>	"\x{295E}",
    '&DownLeftVector;'		=>	"\x{21BD}",
    '&DownLeftVectorBar;'	=>	"\x{2956}",
    '&DownRightTeeVector;'	=>	"\x{295F}",
    '&DownRightVector;'		=>	"\x{21C1}",
    '&DownRightVectorBar;'	=>	"\x{2957}",
    '&DownTee;'			=>	"\x{22A4}",
    '&DownTeeArrow;'		=>	"\x{21A7}",
    '&Downarrow;'		=>	"\x{21D3}",
    '&Dstrok;'			=>	"\x{0110}",
    '&EEacgr;'			=>	"\x{0389}",
    '&EEcigr;'			=>	"\x{0397}\x{1FC0}",
    '&EEgr;'			=>	"\x{0397}",
    '&EEgr;'			=>	"\x{0397}",
    '&EEgragr;'			=>	"\x{1FCA}",
    '&EEragr;'			=>	"\x{1F2D}",
    '&EErcgr;'			=>	"\x{1F2F}",
    '&EErggr;'			=>	"\x{1F2B}",
    '&EErougr;'			=>	"\x{1F29}",
    '&EEsagr;'			=>	"\x{1F2C}",
    '&EEscgr;'			=>	"\x{1F2E}",
    '&EEsggr;'			=>	"\x{1F2A}",
    '&EEsmogr;'			=>	"\x{1F28}",
    '&ENG;'			=>	"\x{014A}",
    '&ETH;'			=>	"\x{00D0}",
    '&Eacgr;'			=>	"\x{0388}",
    '&Eacugr;'			=>	"\x{1FC9}",
    '&Eacute;'			=>	"\x{00C9}",
    '&Ebar;'			=>	"\x{0112}",
    '&Ecaron;'			=>	"\x{011A}",
    '&Ecirc;'			=>	"\x{00CA}",
    '&Ecy;'			=>	"\x{042D}",
    '&Edot;'			=>	"\x{0116}",
    '&Edotup;'			=>	"\x{0116}",
    '&Egr;'			=>	"\x{0395}",
    '&Egr;'			=>	"\x{0395}",
    '&Egrave;'			=>	"\x{00C8}",
    '&Element;'			=>	"\x{2208}",
    '&Emacr;'			=>	"\x{0112}",
    '&EmptySmallSquare;'	=>	"\x{25FB}",
    '&EmptyVerySmallSquare;'	=>	"\x{25AB}",
    '&Eogon;'			=>	"\x{0118}",
    '&Equal;'			=>	"\x{2A75}",
    '&EqualTilde;'		=>	"\x{2242}",
    '&Equilibrium;'		=>	"\x{21CC}",
    '&Eragr;'			=>	"\x{1F1D}",
    '&Erougr;'			=>	"\x{1F19}",
    '&Esagr;'			=>	"\x{1F1C}",
    '&Esim;'			=>	"\x{2A73}",
    '&Esmogr;'			=>	"\x{1F18}",
    '&Etigr;'			=>	"\x{0395}",
    '&Euml;'			=>	"\x{00CB}",
    '&Exists;'			=>	"\x{2203}",
    '&ExponentialE;'		=>	"\x{2147}",
    '&Fcy;'			=>	"\x{0424}",
    '&FilledSmallSquare;'	=>	"\x{25FC}",
    '&FilledVerySmallSquare;'	=>	"\x{25AA}",
    '&ForAll;'			=>	"\x{2200}",
    '&Fouriertrf;'		=>	"\x{2131}",
    '&GJcy;'			=>	"\x{0403}",
    '&GRAa;'			=>	"\x{1FBB}",
    '&GRAc;'			=>	"\x{0391}\x{1FC0}",
    '&GRAd;'			=>	"\x{0391}",
    '&GRAg;'			=>	"\x{1FBA}",
    '&GRAr;'			=>	"\x{1F09}",
    '&GRAra;'			=>	"\x{1F0D}",
    '&GRArg;'			=>	"\x{1F0B}",
    '&GRAs;'			=>	"\x{1F08}",
    '&GRAsa;'			=>	"\x{1F0C}",
    '&GRAsc;'			=>	"\x{1F0E}",
    '&GRAsg;'			=>	"\x{1F0A}",
    '&GREa;'			=>	"\x{1FC9}",
    '&GREd;'			=>	"\x{0395}",
    '&GREr;'			=>	"\x{1F19}",
    '&GREra;'			=>	"\x{1F1D}",
    '&GREs;'			=>	"\x{1F18}",
    '&GREsa;'			=>	"\x{1F1C}",
    '&GREsc;'			=>	"\x{0395}\x{1FCF}",
    '&GRHc;'			=>	"\x{0397}\x{1FC0}",
    '&GRHg;'			=>	"\x{1FCA}",
    '&GRHr;'			=>	"\x{1F29}",
    '&GRHra;'			=>	"\x{1F2D}",
    '&GRHrc;'			=>	"\x{1F2F}",
    '&GRHrg;'			=>	"\x{1F2B}",
    '&GRHs;'			=>	"\x{1F28}",
    '&GRHsa;'			=>	"\x{1F2C}",
    '&GRHsc;'			=>	"\x{1F2E}",
    '&GRHsg;'			=>	"\x{1F2A}",
    '&GRIa;'			=>	"\x{1FDB}",
    '&GRIc;'			=>	"\x{0399}\x{1FC0}",
    '&GRIg;'			=>	"\x{1FDA}",
    '&GRIr;'			=>	"\x{1F39}",
    '&GRIra;'			=>	"\x{1F3D}",
    '&GRIrg;'			=>	"\x{1F3B}",
    '&GRIs;'			=>	"\x{1F38}",
    '&GRIsa;'			=>	"\x{1F3C}",
    '&GRIsc;'			=>	"\x{1F3E}",
    '&GROa;'			=>	"\x{1FF9}",
    '&GROar;'			=>	"\x{1F4D}",
    '&GROdc;'			=>	"\x{1F49}",
    '&GROg;'			=>	"\x{1FF8}",
    '&GROr;'			=>	"\x{1F49}",
    '&GROra;'			=>	"\x{1F4D}",
    '&GROrg;'			=>	"\x{1F4B}",
    '&GROs;'			=>	"\x{1F48}",
    '&GROsa;'			=>	"\x{1F4C}",
    '&GROsc;'			=>	"\x{39F}\x{1FCF}",
    '&GRRr;'			=>	"\x{1FEC}",
    '&GRRs;'			=>	"\x{1FBD}",
    '&GRST;'			=>	"\x{03A3}",
    '&GRUa;'			=>	"\x{03A5}\x{1FFD}",
    '&GRUr;'			=>	"\x{1F59}",
    '&GRUra;'			=>	"\x{1F5D}",
    '&GRUs;'			=>	"\x{03A5}\x{1FBD}",
    '&GRWc;'			=>	"\x{03A9}\x{1FC0}",
    '&GRWcs;'			=>	"\x{1F6E}",
    '&GRWd;'			=>	"\x{03A9}",
    '&GRWia;'			=>	"\x{1FF7}",
    '&GRWr;'			=>	"\x{1F69}",
    '&GRWra;'			=>	"\x{1F6C}",
    '&GRWrc;'			=>	"\x{1F6F}",
    '&GRWrg;'			=>	"\x{1F6B}",
    '&GRWs;'			=>	"\x{1F68}",
    '&GRWsa;'			=>	"\x{1F6C}",
    '&GRWsc;'			=>	"\x{1F6E}",
    '&GRWst;'			=>	"\x{1F6E}",
    '&Gamma;'			=>	"\x{0393}",
    '&Gammad;'			=>	"\x{03DC}",
    '&Gbreve;'			=>	"\x{011E}",
    '&Gcedil;'			=>	"\x{0122}",
    '&Gcirc;'			=>	"\x{011C}",
    '&Gcy;'			=>	"\x{0413}",
    '&Gdot;'			=>	"\x{0120}",
    '&Gg;'			=>	"\x{22D9}",
    '&Ggr;'			=>	"\x{0393}",
    '&Ggr;'			=>	"\x{0393}",
    '&GreaterEqual;'		=>	"\x{2265}",
    '&GreaterEqualLess;'	=>	"\x{22DB}",
    '&GreaterFullEqual;'	=>	"\x{2267}",
    '&GreaterGreater;'		=>	"\x{2AA2}",
    '&GreaterLess;'		=>	"\x{2277}",
    '&GreaterSlantEqual;'	=>	"\x{2A7E}",
    '&GreaterTilde;'		=>	"\x{2273}",
    '&Gt;'			=>	"\x{226B}",
    '&HARDcy;'			=>	"\x{042A}",
    '&Hacek;'			=>	"\x{02C7}",
    '&Hat;'			=>	"\x{005E}",
    '&Hcirc;'			=>	"\x{0124}",
    '&Hfr;'			=>	"\x{210C}",
    '&HilbertSpace;'		=>	"\x{210B}",
    '&HorizontalLine;'		=>	"\x{2500}",
    '&Hstrok;'			=>	"\x{0126}",
    '&Htilde;'			=>	"\x{0048}\x{0303}",
    '&HumpDownHump;'		=>	"\x{224E}",
    '&HumpEqual;'		=>	"\x{224F}",
    '&IEcy;'			=>	"\x{0415}",
    '&IJlig;'			=>	"\x{0132}",
    '&IOcy;'			=>	"\x{0401}",
    '&Iacgr;'			=>	"\x{038A}",
    '&Iacugr;'			=>	"\x{1FDB}",
    '&Iacute;'			=>	"\x{00CD}",
    '&Ibar;'			=>	"\x{012A}",
    '&Icirc;'			=>	"\x{00CE}",
    '&Icirgr;'			=>	"\x{1FC0}",
    '&Icy;'			=>	"\x{0418}",
    '&Idigr;'			=>	"\x{03AA}",
    '&Idot;'			=>	"\x{0130}",
    '&Ifr;'			=>	"\x{2111}",
    '&Igr;'			=>	"\x{0399}",
    '&Igr;'			=>	"\x{0399}",
    '&Igragr;'			=>	"\x{1FDA}",
    '&Igrave;'			=>	"\x{00CC}",
    '&Igvgr;'			=>	"\x{1FDA}",
    '&Im;'			=>	"\x{2111}",
    '&Imacr;'			=>	"\x{012A}",
    '&ImaginaryI;'		=>	"\x{2148}",
    '&Implies;'			=>	"\x{21D2}",
    '&Int;'			=>	"\x{222C}",
    '&Integral;'		=>	"\x{222B}",
    '&Intersection;'		=>	"\x{22C2}",
    '&InvisibleComma;'		=>	"\x{2063}",
    '&InvisibleTimes;'		=>	"\x{2062}",
    '&Iogon;'			=>	"\x{012E}",
    '&Iragr;'			=>	"\x{1F3D}",
    '&Irggr;'			=>	"\x{1F3B}",
    '&Irougr;'			=>	"\x{1F39}",
    '&Isagr;'			=>	"\x{1F3C}",
    '&Iscgr;'			=>	"\x{1F3E}",
    '&Ishort;'			=>	"\x{12C}",
    '&Ismogr;'			=>	"\x{1F38}",
    '&Itilde;'			=>	"\x{0128}",
    '&Iukcy;'			=>	"\x{0406}",
    '&Iuml;'			=>	"\x{00CF}",
    '&Jcirc;'			=>	"\x{0134}",
    '&Jcy;'			=>	"\x{0419}",
    '&Jsercy;'			=>	"\x{0408}",
    '&Jukcy;'			=>	"\x{0404}",
    '&KHcy;'			=>	"\x{0425}",
    '&KHgr;'			=>	"\x{03A7}",
    '&KHgr;'			=>	"\x{03A7}",
    '&KJcy;'			=>	"\x{040C}",
    '&Kcedil;'			=>	"\x{0136}",
    '&Kcy;'			=>	"\x{041A}",
    '&Kgr;'			=>	"\x{039A}",
    '&Kgr;'			=>	"\x{039A}",
    '&LJcy;'			=>	"\x{0409}",
    '&Lacute;'			=>	"\x{0139}",
    '&Lambda;'			=>	"\x{039B}",
    '&Lang;'			=>	"\x{300A}",
    '&Laplacetrf;'		=>	"\x{2112}",
    '&Larr;'			=>	"\x{219E}",
    '&Lcaron;'			=>	"\x{013D}",
    '&Lcedil;'			=>	"\x{013B}",
    '&Lcy;'			=>	"\x{041B}",
    '&LeftAngleBracket;'	=>	"\x{2329}",
    '&LeftArrow;'		=>	"\x{2190}",
    '&LeftArrowBar;'		=>	"\x{21E4}",
    '&LeftArrowRightArrow;'	=>	"\x{21C6}",
    '&LeftCeiling;'		=>	"\x{2308}",
    '&LeftDoubleBracket;'	=>	"\x{301A}",
    '&LeftDownTeeVector;'	=>	"\x{2961}",
    '&LeftDownVector;'		=>	"\x{21C3}",
    '&LeftDownVectorBar;'	=>	"\x{2959}",
    '&LeftFloor;'		=>	"\x{230A}",
    '&LeftRightArrow;'		=>	"\x{2194}",
    '&LeftRightVector;'		=>	"\x{294E}",
    '&LeftTee;'			=>	"\x{22A3}",
    '&LeftTeeArrow;'		=>	"\x{21A4}",
    '&LeftTeeVector;'		=>	"\x{295A}",
    '&LeftTriangle;'		=>	"\x{22B2}",
    '&LeftTriangleBar;'		=>	"\x{29CF}",
    '&LeftTriangleEqual;'	=>	"\x{22B4}",
    '&LeftUpDownVector;'	=>	"\x{2951}",
    '&LeftUpTeeVector;'		=>	"\x{2960}",
    '&LeftUpVector;'		=>	"\x{21BF}",
    '&LeftUpVectorBar;'		=>	"\x{2958}",
    '&LeftVector;'		=>	"\x{21BC}",
    '&LeftVectorBar;'		=>	"\x{2952}",
    '&Leftarrow;'		=>	"\x{21D0}",
    '&Leftrightarrow;'		=>	"\x{21D4}",
    '&LessEqualGreater;'	=>	"\x{22DA}",
    '&LessFullEqual;'		=>	"\x{2266}",
    '&LessGreater;'		=>	"\x{2276}",
    '&LessLess;'		=>	"\x{2AA1}",
    '&LessSlantEqual;'		=>	"\x{2A7D}",
    '&LessTilde;'		=>	"\x{2272}",
    '&Lgr;'			=>	"\x{039B}",
    '&Lgr;'			=>	"\x{039B}",
    '&Ll;'			=>	"\x{22D8}",
    '&Lleftarrow;'		=>	"\x{21DA}",
    '&Lmidot;'			=>	"\x{013F}",
    '&LongLeftArrow;'		=>	"\x{27F5}",
    '&LongLeftRightArrow;'	=>	"\x{27F7}",
    '&LongRightArrow;'		=>	"\x{27F6}",
    '&Longleftarrow;'		=>	"\x{27F8}",
    '&Longleftrightarrow;'	=>	"\x{27FA}",
    '&Longrightarrow;'		=>	"\x{27F9}",
    '&LowerLeftArrow;'		=>	"\x{2199}",
    '&LowerRightArrow;'		=>	"\x{2198}",
    '&Lsh;'			=>	"\x{21B0}",
    '&Lstrok;'			=>	"\x{0141}",
    '&Lt;'			=>	"\x{226A}",
    '&Map;'			=>	"\x{2905}",
    '&Mbar;'			=>	"\x{4D}\x{304}",
    '&Mcy;'			=>	"\x{041C}",
    '&MediumSpace;'		=>	"\x{205F}",
    '&Mellintrf;'		=>	"\x{2133}",
    '&Mgr;'			=>	"\x{039C}",
    '&Mgr;'			=>	"\x{039C}",
    '&MinusPlus;'		=>	"\x{2213}",
    '&NJcy;'			=>	"\x{040A}",
    '&Nacute;'			=>	"\x{0143}",
    '&Ncaron;'			=>	"\x{0147}",
    '&Ncedil;'			=>	"\x{0145}",
    '&Ncy;'			=>	"\x{041D}",
    '&NegativeMediumSpace;'	=>	"\x{200B}",
    '&NegativeThickSpace;'	=>	"\x{200B}",
    '&NegativeThinSpace;'	=>	"\x{200B}",
    '&NegativeVeryThinSpace;'	=>	"\x{200B}",
    '&NestedGreaterGreater;'	=>	"\x{226B}",
    '&NestedLessLess;'		=>	"\x{226A}",
    '&Ngr;'			=>	"\x{039D}",
    '&Ngr;'			=>	"\x{039D}",
    '&NoBreak;'			=>	"\x{2060}",
    '&NonBreakingSpace;'	=>	"\x{00A0}",
    '&Not;'			=>	"\x{2AEC}",
    '&NotCongruent;'		=>	"\x{2262}",
    '&NotCupCap;'		=>	"\x{226D}",
    '&NotDoubleVerticalBar;'	=>	"\x{2226}",
    '&NotElement;'		=>	"\x{2209}",
    '&NotEqual;'		=>	"\x{2260}",
    '&NotEqualTilde;'		=>	"\x{2242}",
    '&NotExists;'		=>	"\x{2204}",
    '&NotGreater;'		=>	"\x{226F}",
    '&NotGreaterEqual;'		=>	"\x{2271}",
    '&NotGreaterFullEqual;'	=>	"\x{2266}",
    '&NotGreaterGreater;'	=>	"\x{226B}",
    '&NotGreaterLess;'		=>	"\x{2279}",
    '&NotGreaterSlantEqual;'	=>	"\x{2A7E}",
    '&NotGreaterTilde;'		=>	"\x{2275}",
    '&NotHumpDownHump;'		=>	"\x{224E}",
    '&NotHumpEqual;'		=>	"\x{224F}",
    '&NotLeftTriangle;'		=>	"\x{22EA}",
    '&NotLeftTriangleBar;'	=>	"\x{29CF}",
    '&NotLeftTriangleEqual;'	=>	"\x{22EC}",
    '&NotLess;'			=>	"\x{226E}",
    '&NotLessEqual;'		=>	"\x{2270}",
    '&NotLessGreater;'		=>	"\x{2278}",
    '&NotLessLess;'		=>	"\x{226A}",
    '&NotLessSlantEqual;'	=>	"\x{2A7D}",
    '&NotLessTilde;'		=>	"\x{2274}",
    '&NotNestedGreaterGreater;'	=>	"\x{2AA2}",
    '&NotNestedLessLess;'	=>	"\x{2AA1}",
    '&NotPrecedes;'		=>	"\x{2280}",
    '&NotPrecedesEqual;'	=>	"\x{2AAF}",
    '&NotPrecedesSlantEqual;'	=>	"\x{22E0}",
    '&NotReverseElement;'	=>	"\x{220C}",
    '&NotRightTriangle;'	=>	"\x{22EB}",
    '&NotRightTriangleBar;'	=>	"\x{29D0}",
    '&NotRightTriangleEqual;'	=>	"\x{22ED}",
    '&NotSquareSubset;'		=>	"\x{228F}",
    '&NotSquareSubsetEqual;'	=>	"\x{22E2}",
    '&NotSquareSuperset;'	=>	"\x{2290}",
    '&NotSquareSupersetEqual;'	=>	"\x{22E3}",
    '&NotSubset;'		=>	"\x{2282}",
    '&NotSubsetEqual;'		=>	"\x{2288}",
    '&NotSucceeds;'		=>	"\x{2281}",
    '&NotSucceedsEqual;'	=>	"\x{2AB0}",
    '&NotSucceedsSlantEqual;'	=>	"\x{22E1}",
    '&NotSucceedsTilde;'	=>	"\x{227F}",
    '&NotSuperset;'		=>	"\x{2283}",
    '&NotSupersetEqual;'	=>	"\x{2289}",
    '&NotTilde;'		=>	"\x{2241}",
    '&NotTildeEqual;'		=>	"\x{2244}",
    '&NotTildeFullEqual;'	=>	"\x{2247}",
    '&NotTildeTilde;'		=>	"\x{2249}",
    '&NotVerticalBar;'		=>	"\x{2224}",
    '&Ntilde;'			=>	"\x{00D1}",
    '&OElig;'			=>	"\x{0152}",
    '&OHacgr;'			=>	"\x{038F}",
    '&OHcirgr;'			=>	"\x{03A9}\x{1FC0}",
    '&OHgr;'			=>	"\x{03A9}",
    '&OHgr;'			=>	"\x{03A9}",
    '&OHragr;'			=>	"\x{1F6D}",
    '&OHrcgr;'			=>	"\x{1F6F}",
    '&OHrggr;'			=>	"\x{1F6B}",
    '&OHrougr;'			=>	"\x{1F69}",
    '&OHsagr;'			=>	"\x{1F6C}",
    '&OHscgr;'			=>	"\x{1F6E}",
    '&OHsmogr;'			=>	"\x{1F68}",
    '&Oacgr;'			=>	"\x{038C}",
    '&Oacugr;'			=>	"\x{1FF9}",
    '&Oacute;'			=>	"\x{00D3}",
    '&Obar;'			=>	"\x{014C}",
    '&Ocirc;'			=>	"\x{00D4}",
    '&Ocy;'			=>	"\x{041E}",
    '&Odblac;'			=>	"\x{0150}",
    '&Ogr;'			=>	"\x{039F}",
    '&Ogr;'			=>	"\x{039F}",
    '&Ogragr;'			=>	"\x{1FF8}",
    '&Ograve;'			=>	"\x{00D2}",
    '&Omacr;'			=>	"\x{014C}",
    '&Omega;'			=>	"\x{03A9}",
    '&OpenCurlyDoubleQuote;'	=>	"\x{201C}",
    '&OpenCurlyQuote;'		=>	"\x{2018}",
    '&Or;'			=>	"\x{2A54}",
    '&Oragr;'			=>	"\x{1F4D}",
    '&Orggr;'			=>	"\x{1F4B}",
    '&Orougr;'			=>	"\x{1F49}",
    '&Osagr;'			=>	"\x{1F4C}",
    '&Oslash;'			=>	"\x{00D8}",
    '&Osmogr;'			=>	"\x{1F48}",
    '&Otilde;'			=>	"\x{00D5}",
    '&Otimes;'			=>	"\x{2A37}",
    '&Ouml;'			=>	"\x{00D6}",
    '&OverBar;'			=>	"\x{00AF}",
    '&OverBrace;'		=>	"\x{FE37}",
    '&OverBracket;'		=>	"\x{23B4}",
    '&OverParenthesis;'		=>	"\x{FE35}",
    '&PHgr;'			=>	"\x{03A6}",
    '&PHgr;'			=>	"\x{03C6}",
    '&PSgr;'			=>	"\x{03A8}",
    '&PSgr;'			=>	"\x{03C8}",
    '&PartialD;'		=>	"\x{2202}",
    '&Pcy;'			=>	"\x{041F}",
    '&Pgr;'			=>	"\x{03A0}",
    '&Pgr;'			=>	"\x{03A0}",
    '&Phi;'			=>	"\x{03A6}",
    '&Pi;'			=>	"\x{03A0}",
    '&PlusMinus;'		=>	"\x{00B1}",
    '&Poincareplane;'		=>	"\x{210C}",
    '&Pr;'			=>	"\x{2ABB}",
    '&Precedes;'		=>	"\x{227A}",
    '&PrecedesEqual;'		=>	"\x{2AAF}",
    '&PrecedesSlantEqual;'	=>	"\x{227C}",
    '&PrecedesTilde;'		=>	"\x{227E}",
    '&Prime;'			=>	"\x{2033}",
    '&Product;'			=>	"\x{220F}",
    '&Proportion;'		=>	"\x{2237}",
    '&Proportional;'		=>	"\x{221D}",
    '&Psi;'			=>	"\x{03A8}",
    '&Qbar;'			=>	"\x{0051}\x{0304}",
    '&RBarr;'			=>	"\x{2910}",
    '&Racute;'			=>	"\x{0154}",
    '&Rang;'			=>	"\x{300B}",
    '&Rarr;'			=>	"\x{21A0}",
    '&Rarrtl;'			=>	"\x{2916}",
    '&Rcaron;'			=>	"\x{0158}",
    '&Rcedil;'			=>	"\x{0156}",
    '&Rcy;'			=>	"\x{0420}",
    '&Re;'			=>	"\x{211C}",
    '&ReverseElement;'		=>	"\x{220B}",
    '&ReverseEquilibrium;'	=>	"\x{21CB}",
    '&ReverseUpEquilibrium;'	=>	"\x{296F}",
    '&Rfr;'			=>	"\x{211C}",
    '&Rgr;'			=>	"\x{03A1}",
    '&Rgr;'			=>	"\x{03A1}",
    '&RightAngleBracket;'	=>	"\x{232A}",
    '&RightArrow;'		=>	"\x{2192}",
    '&RightArrowBar;'		=>	"\x{21E5}",
    '&RightArrowLeftArrow;'	=>	"\x{21C4}",
    '&RightCeiling;'		=>	"\x{2309}",
    '&RightDoubleBracket;'	=>	"\x{301B}",
    '&RightDownTeeVector;'	=>	"\x{295D}",
    '&RightDownVector;'		=>	"\x{21C2}",
    '&RightDownVectorBar;'	=>	"\x{2955}",
    '&RightFloor;'		=>	"\x{230B}",
    '&RightTee;'		=>	"\x{22A2}",
    '&RightTeeArrow;'		=>	"\x{21A6}",
    '&RightTeeVector;'		=>	"\x{295B}",
    '&RightTriangle;'		=>	"\x{22B3}",
    '&RightTriangleBar;'	=>	"\x{29D0}",
    '&RightTriangleEqual;'	=>	"\x{22B5}",
    '&RightUpDownVector;'	=>	"\x{294F}",
    '&RightUpTeeVector;'	=>	"\x{295C}",
    '&RightUpVector;'		=>	"\x{21BE}",
    '&RightUpVectorBar;'	=>	"\x{2954}",
    '&RightVector;'		=>	"\x{21C0}",
    '&RightVectorBar;'		=>	"\x{2953}",
    '&Rightarrow;'		=>	"\x{21D2}",
    '&RoundImplies;'		=>	"\x{2970}",
    '&Rrightarrow;'		=>	"\x{21DB}",
    '&Rrougr;'			=>	"\x{03A1}\x{1FFE}",
    '&Rsh;'			=>	"\x{21B1}",
    '&RuleDelayed;'		=>	"\x{29F4}",
    '&Rx;'			=>	"\x{211E}",
    '&SHCHcy;'			=>	"\x{0429}",
    '&SHcy;'			=>	"\x{0428}",
    '&SOFTcy;'			=>	"\x{042C}",
    '&Sacute;'			=>	"\x{015A}",
    '&Sc;'			=>	"\x{2ABC}",
    '&Scaron;'			=>	"\x{0160}",
    '&Scedil;'			=>	"\x{015E}",
    '&Scirc;'			=>	"\x{015C}",
    '&Scy;'			=>	"\x{0421}",
    '&Sdot;'			=>	"\x{1E62}",
    '&Sgr;'			=>	"\x{03A3}",
    '&Sgr;'			=>	"\x{03A3}",
    '&Shacek;'			=>	"\x{0160}",
    '&ShortDownArrow;'		=>	"\x{2193}",
    '&ShortLeftArrow;'		=>	"\x{2190}",
    '&ShortRightArrow;'		=>	"\x{2192}",
    '&ShortUpArrow;'		=>	"\x{2191}",
    '&Sigma;'			=>	"\x{03A3}",
    '&Slungr;'			=>	"\x{03F2}",
    '&SmallCircle;'		=>	"\x{2218}",
    '&Sqrt;'			=>	"\x{221A}",
    '&Square;'			=>	"\x{25A1}",
    '&SquareIntersection;'	=>	"\x{2293}",
    '&SquareSubset;'		=>	"\x{228F}",
    '&SquareSubsetEqual;'	=>	"\x{2291}",
    '&SquareSuperset;'		=>	"\x{2290}",
    '&SquareSupersetEqual;'	=>	"\x{2292}",
    '&SquareUnion;'		=>	"\x{2294}",
    '&Star;'			=>	"\x{22C6}",
    '&Sub;'			=>	"\x{22D0}",
    '&Subset;'			=>	"\x{22D0}",
    '&SubsetEqual;'		=>	"\x{2286}",
    '&Succeeds;'		=>	"\x{227B}",
    '&SucceedsEqual;'		=>	"\x{2AB0}",
    '&SucceedsSlantEqual;'	=>	"\x{227D}",
    '&SucceedsTilde;'		=>	"\x{227F}",
    '&SuchThat;'		=>	"\x{220B}",
    '&Sum;'			=>	"\x{2211}",
    '&Sup;'			=>	"\x{22D1}",
    '&Superset;'		=>	"\x{2283}",
    '&SupersetEqual;'		=>	"\x{2287}",
    '&Supset;'			=>	"\x{22D1}",
    '&THORN;'			=>	"\x{00DE}",
    '&THgr;'			=>	"\x{0398}",
    '&THgr;'			=>	"\x{0398}",
    '&TSHcy;'			=>	"\x{040B}",
    '&TScy;'			=>	"\x{0426}",
    '&Tcaron;'			=>	"\x{0164}",
    '&Tcedil;'			=>	"\x{0162}",
    '&Tcy;'			=>	"\x{0422}",
    '&Tgr;'			=>	"\x{03A4}",
    '&Tgr;'			=>	"\x{03A4}",
    '&Therefore;'		=>	"\x{2234}",
    '&Theta;'			=>	"\x{0398}",
    '&ThickSpace;'		=>	"\x{2009}",
    '&ThinSpace;'		=>	"\x{2009}",
    '&Tilde;'			=>	"\x{223C}",
    '&TildeEqual;'		=>	"\x{2243}",
    '&TildeFullEqual;'		=>	"\x{2245}",
    '&TildeTilde;'		=>	"\x{2248}",
    '&TripleDot;'		=>	"\x{20DB}",
    '&Tstrok;'			=>	"\x{0166}",
    '&Uacgr;'			=>	"\x{038E}",
    '&Uacute;'			=>	"\x{00DA}",
    '&Uarr;'			=>	"\x{219F}",
    '&Uarrocir;'		=>	"\x{2949}",
    '&Ubar;'			=>	"\x{016A}",
    '&Ubrcy;'			=>	"\x{040E}",
    '&Ubreve;'			=>	"\x{016C}",
    '&Ucirc;'			=>	"\x{00DB}",
    '&Ucy;'			=>	"\x{0423}",
    '&Udblac;'			=>	"\x{0170}",
    '&Udigr;'			=>	"\x{03AB}",
    '&Ugr;'			=>	"\x{03A5}",
    '&Ugrave;'			=>	"\x{00D9}",
    '&Umacr;'			=>	"\x{016A}",
    '&UnderBar;'		=>	"\x{0332}",
    '&UnderBrace;'		=>	"\x{FE38}",
    '&UnderBracket;'		=>	"\x{23B5}",
    '&UnderParenthesis;'	=>	"\x{FE36}",
    '&Union;'			=>	"\x{22C3}",
    '&UnionPlus;'		=>	"\x{228E}",
    '&Uogon;'			=>	"\x{0172}",
    '&UpArrow;'			=>	"\x{2191}",
    '&UpArrowBar;'		=>	"\x{2912}",
    '&UpArrowDownArrow;'	=>	"\x{21C5}",
    '&UpDownArrow;'		=>	"\x{2195}",
    '&UpEquilibrium;'		=>	"\x{296E}",
    '&UpTee;'			=>	"\x{22A5}",
    '&UpTeeArrow;'		=>	"\x{21A5}",
    '&Uparrow;'			=>	"\x{21D1}",
    '&Updownarrow;'		=>	"\x{21D5}",
    '&UpperLeftArrow;'		=>	"\x{2196}",
    '&UpperRightArrow;'		=>	"\x{2197}",
    '&Upsi;'			=>	"\x{03D2}",
    '&Upsilon;'			=>	"\x{03A5}",
    '&Uragr;'			=>	"\x{1F5D}",
    '&Uring;'			=>	"\x{016E}",
    '&Urougr;'			=>	"\x{1F59}",
    '&Usmogr;'			=>	"\x{03A5}\x{1FBD}",
    '&Utilde;'			=>	"\x{0168}",
    '&Uuml;'			=>	"\x{00DC}",
    '&VDash;'			=>	"\x{22AB}",
    '&Vbar;'			=>	"\x{2AEB}",
    '&Vcy;'			=>	"\x{0412}",
    '&Vdash;'			=>	"\x{22A9}",
    '&Vdashl;'			=>	"\x{2AE6}",
    '&Vee;'			=>	"\x{22C1}",
    '&Verbar;'			=>	"\x{2016}",
    '&Vert;'			=>	"\x{2016}",
    '&VerticalBar;'		=>	"\x{2223}",
    '&VerticalLine;'		=>	"\x{007C}",
    '&VerticalSeparator;'	=>	"\x{2758}",
    '&VerticalTilde;'		=>	"\x{2240}",
    '&VeryThinSpace;'		=>	"\x{200A}",
    '&Vvdash;'			=>	"\x{22AA}",
    '&Vx;'			=>	"\x{2123}",
    '&Wcirc;'			=>	"\x{0174}",
    '&Wedge;'			=>	"\x{22C0}",
    '&Xgr;'			=>	"\x{039E}",
    '&Xgr;'			=>	"\x{039E}",
    '&Xi;'			=>	"\x{039E}",
    '&YAcy;'			=>	"\x{042F}",
    '&YIcy;'			=>	"\x{0407}",
    '&YOGH;'			=>	"\x{021C}",
    '&YUcy;'			=>	"\x{042E}",
    '&Yacute;'			=>	"\x{00DD}",
    '&Ycirc;'			=>	"\x{0176}",
    '&Ycy;'			=>	"\x{042B}",
    '&Yuml;'			=>	"\x{0178}",
    '&ZHcy;'			=>	"\x{0416}",
    '&Zacute;'			=>	"\x{0179}",
    '&Zcaron;'			=>	"\x{017D}",
    '&Zcy;'			=>	"\x{0417}",
    '&Zdot;'			=>	"\x{017B}",
    '&ZeroWidthSpace;'		=>	"\x{200B}",
    '&Zfr;'			=>	"\x{2128}",
    '&Zgr;'			=>	"\x{0396}",
    '&Zgr;'			=>	"\x{0396}",
    '&aacgr;'			=>	"\x{03AC}",
    '&aacgr;'			=>	"\x{1F71}",
    '&aacugr;'			=>	"\x{1F71}",
    '&aacute;'			=>	"\x{00E1}",
    '&aaigr;'			=>	"\x{1FB4}",
    '&abar;'			=>	"\x{0101}",
    '&abreve;'			=>	"\x{0103}",
    '&ac;'			=>	"\x{223E}",
    '&acE;'			=>	"\x{223E}",
    '&acd;'			=>	"\x{223F}",
    '&acigr;'			=>	"\x{1FB7}",
    '&acirc;'			=>	"\x{00E2}",
    '&acirgr;'			=>	"\x{1FB6}",
    '&acugr;'			=>	"\x{1FFD}",
    '&acute;'			=>	"\x{00B4}",
    '&acy;'			=>	"\x{0430}",
    '&adot;'			=>	"\x{1EA1}",
    '&aelig;'			=>	"\x{00E6}",
    '&aeligac;'			=>	"\x{E6}",
    '&aeligsh;'			=>	"\x{E6}",
    '&af;'			=>	"\x{2061}",
    '&agigr;'			=>	"\x{1FB2}",
    '&agr;'			=>	"\x{03B1}",
    '&agr;'			=>	"\x{03B1}",
    '&agragr;'			=>	"\x{1F70}",
    '&agrave;'			=>	"\x{00E0}",
    '&agvgr;'			=>	"\x{1F70}",
    '&aiotgr;'			=>	"\x{1FB3}",
    '&aleph;'			=>	"\x{2135}",
    '&alpha;'			=>	"\x{03B1}",
    '&amacr;'			=>	"\x{0101}",
    '&amalg;'			=>	"\x{2A3F}",
    '&amp;'			=>	"\x{0026}",
    '&and;'			=>	"\x{2227}",
    '&andand;'			=>	"\x{2A55}",
    '&andd;'			=>	"\x{2A5C}",
    '&andslope;'		=>	"\x{2A58}",
    '&andv;'			=>	"\x{2A5A}",
    '&ang;'			=>	"\x{2220}",
    '&ange;'			=>	"\x{29A4}",
    '&angle;'			=>	"\x{2220}",
    '&angmsd;'			=>	"\x{2221}",
    '&angmsdaa;'		=>	"\x{29A8}",
    '&angmsdab;'		=>	"\x{29A9}",
    '&angmsdac;'		=>	"\x{29AA}",
    '&angmsdad;'		=>	"\x{29AB}",
    '&angmsdae;'		=>	"\x{29AC}",
    '&angmsdaf;'		=>	"\x{29AD}",
    '&angmsdag;'		=>	"\x{29AE}",
    '&angmsdah;'		=>	"\x{29AF}",
    '&angrt;'			=>	"\x{221F}",
    '&angrtvb;'			=>	"\x{22BE}",
    '&angrtvbd;'		=>	"\x{299D}",
    '&angsph;'			=>	"\x{2222}",
    '&angst;'			=>	"\x{212B}",
    '&angzarr;'			=>	"\x{237C}",
    '&aogon;'			=>	"\x{0105}",
    '&ap;'			=>	"\x{2248}",
    '&apE;'			=>	"\x{2A70}",
    '&apacir;'			=>	"\x{2A6F}",
    '&ape;'			=>	"\x{224A}",
    '&apid;'			=>	"\x{224B}",
    '&apos;'			=>	"\x{0027}",
    '&apos;'			=>	"\x{1FBD}",
    '&aposgr;'			=>	"\x{1FBD}",
    '&approx;'			=>	"\x{2248}",
    '&approxeq;'		=>	"\x{224A}",
    '&aragr;'			=>	"\x{1F05}",
    '&araigr;'			=>	"\x{1F85}",
    '&arcgr;'			=>	"\x{1F07}",
    '&arcigr;'			=>	"\x{1F87}",
    '&arggr;'			=>	"\x{1F03}",
    '&argigr;'			=>	"\x{1F83}",
    '&arigr;'			=>	"\x{1F81}",
    '&aring;'			=>	"\x{00E5}",
    '&arougr;'			=>	"\x{1F01}",
    '&asagr;'			=>	"\x{1F04}",
    '&asaigr;'			=>	"\x{1F84}",
    '&ascgr;'			=>	"\x{1F06}",
    '&ascigr;'			=>	"\x{1F86}",
    '&asggr;'			=>	"\x{1F02}",
    '&asgigr;'			=>	"\x{1F82}",
    '&ashort;'			=>	"\x{0103}",
    '&asigr;'			=>	"\x{1F80}",
    '&asmogr;'			=>	"\x{1F00}",
    '&ast;'			=>	"\x{002A}",
    '&asymp;'			=>	"\x{2248}",
    '&asympeq;'			=>	"\x{224D}",
    '&atigr;'			=>	"\x{1FB6}",
    '&atilde;'			=>	"\x{00E3}",
    '&auml;'			=>	"\x{00E4}",
    '&awconint;'		=>	"\x{2233}",
    '&awint;'			=>	"\x{2A11}",
    '&bNot;'			=>	"\x{2AED}",
    '&backcong;'		=>	"\x{224C}",
    '&backepsilon;'		=>	"\x{03F6}",
    '&backprime;'		=>	"\x{2035}",
    '&backsim;'			=>	"\x{223D}",
    '&backsimeq;'		=>	"\x{22CD}",
    '&barvee;'			=>	"\x{22BD}",
    '&barwed;'			=>	"\x{2305}",
    '&barwedge;'		=>	"\x{2305}",
    '&bbar;'			=>	"\x{0180}",
    '&bbrk;'			=>	"\x{23B5}",
    '&bbrktbrk;'		=>	"\x{23B6}",
    '&bcong;'			=>	"\x{224C}",
    '&bcy;'			=>	"\x{0431}",
    '&becaus;'			=>	"\x{2235}",
    '&because;'			=>	"\x{2235}",
    '&bemptyv;'			=>	"\x{29B0}",
    '&bepsi;'			=>	"\x{03F6}",
    '&bernou;'			=>	"\x{212C}",
    '&beta;'			=>	"\x{03B2}",
    '&beth;'			=>	"\x{2136}",
    '&between;'			=>	"\x{226C}",
    '&bgr;'			=>	"\x{03B2}",
    '&bgr;'			=>	"\x{03B2}",
    '&bigcap;'			=>	"\x{22C2}",
    '&bigcirc;'			=>	"\x{25EF}",
    '&bigcup;'			=>	"\x{22C3}",
    '&bigodot;'			=>	"\x{2A00}",
    '&bigoplus;'		=>	"\x{2A01}",
    '&bigotimes;'		=>	"\x{2A02}",
    '&bigsqcup;'		=>	"\x{2A06}",
    '&bigstar;'			=>	"\x{2605}",
    '&bigtriangledown;'		=>	"\x{25BD}",
    '&bigtriangleup;'		=>	"\x{25B3}",
    '&biguplus;'		=>	"\x{2A04}",
    '&bigvee;'			=>	"\x{22C1}",
    '&bigwedge;'		=>	"\x{22C0}",
    '&bkarow;'			=>	"\x{290D}",
    '&blacklozenge;'		=>	"\x{29EB}",
    '&blacksquare;'		=>	"\x{25AA}",
    '&blacktriangle;'		=>	"\x{25B4}",
    '&blacktriangledown;'	=>	"\x{25BE}",
    '&blacktriangleleft;'	=>	"\x{25C2}",
    '&blacktriangleright;'	=>	"\x{25B8}",
    '&blank;'			=>	"\x{2423}",
    '&blk12;'			=>	"\x{2592}",
    '&blk14;'			=>	"\x{2591}",
    '&blk34;'			=>	"\x{2593}",
    '&block;'			=>	"\x{2588}",
    '&bne;'			=>	"\x{003D}",
    '&bnequiv;'			=>	"\x{2261}",
    '&bnot;'			=>	"\x{2310}",
    '&bot;'			=>	"\x{22A5}",
    '&bottom;'			=>	"\x{22A5}",
    '&bowtie;'			=>	"\x{22C8}",
    '&boxbox;'			=>	"\x{29C9}",
    '&boxminus;'		=>	"\x{229F}",
    '&boxplus;'			=>	"\x{229E}",
    '&boxtimes;'		=>	"\x{22A0}",
    '&bprime;'			=>	"\x{2035}",
    '&breve;'			=>	"\x{02D8}",
    '&brvbar;'			=>	"\x{00A6}",
    '&bsemi;'			=>	"\x{204F}",
    '&bsim;'			=>	"\x{223D}",
    '&bsime;'			=>	"\x{22CD}",
    '&bsol;'			=>	"\x{005C}",
    '&bsolb;'			=>	"\x{29C5}",
    '&bsolhsub;'		=>	"\x{005C}",
    '&bull;'			=>	"\x{2022}",
    '&bullet;'			=>	"\x{2022}",
    '&bump;'			=>	"\x{224E}",
    '&bumpE;'			=>	"\x{2AAE}",
    '&bumpe;'			=>	"\x{224F}",
    '&bumpeq;'			=>	"\x{224F}",
    '&cacute;'			=>	"\x{0107}",
    '&cap;'			=>	"\x{2229}",
    '&capand;'			=>	"\x{2A44}",
    '&capbrcup;'		=>	"\x{2A49}",
    '&capcap;'			=>	"\x{2A4B}",
    '&capcup;'			=>	"\x{2A47}",
    '&capdot;'			=>	"\x{2A40}",
    '&caps;'			=>	"\x{2229}",
    '&caret;'			=>	"\x{2041}",
    '&cbar;'			=>	"\x{0063}\x{0304}",
    '&cbreve;'			=>	"\x{0063}\x{0306}",
    '&ccaps;'			=>	"\x{2A4D}",
    '&ccaron;'			=>	"\x{010D}",
    '&ccedil;'			=>	"\x{00E7}",
    '&ccirc;'			=>	"\x{0109}",
    '&ccups;'			=>	"\x{2A4C}",
    '&ccupssm;'			=>	"\x{2A50}",
    '&cdot;'			=>	"\x{010B}",
    '&cemptyv;'			=>	"\x{29B2}",
    '&cent;'			=>	"\x{00A2}",
    '&centerdot;'		=>	"\x{00B7}",
    '&chacek;'			=>	"\x{010D}",
    '&chcy;'			=>	"\x{0447}",
    '&check;'			=>	"\x{2713}",
    '&checkmark;'		=>	"\x{2713}",
    '&chi;'			=>	"\x{03C7}",
    '&cir;'			=>	"\x{25CB}",
    '&cirE;'			=>	"\x{29C3}",
    '&circeq;'			=>	"\x{2257}",
    '&circlearrowleft;'		=>	"\x{21BA}",
    '&circlearrowright;'	=>	"\x{21BB}",
    '&circledR;'		=>	"\x{00AE}",
    '&circledS;'		=>	"\x{24C8}",
    '&circledast;'		=>	"\x{229B}",
    '&circledcirc;'		=>	"\x{229A}",
    '&circleddash;'		=>	"\x{229D}",
    '&cire;'			=>	"\x{2257}",
    '&cirfnint;'		=>	"\x{2A10}",
    '&cirgr;'			=>	"\x{1FC0}",
    '&cirmid;'			=>	"\x{2AEF}",
    '&cirscir;'			=>	"\x{29C2}",
    '&clubs;'			=>	"\x{2663}",
    '&clubsuit;'		=>	"\x{2663}",
    '&cmacr;'			=>	"\x{0063}\x{0304}",
    '&colgr;'			=>	"\x{00B7}",
    '&colon;'			=>	"\x{003A}",
    '&colone;'			=>	"\x{2254}",
    '&coloneq;'			=>	"\x{2254}",
    '&comma;'			=>	"\x{002C}",
    '&commat;'			=>	"\x{0040}",
    '&comp;'			=>	"\x{2201}",
    '&compfn;'			=>	"\x{2218}",
    '&complement;'		=>	"\x{2201}",
    '&complexes;'		=>	"\x{2102}",
    '&cong;'			=>	"\x{2245}",
    '&congdot;'			=>	"\x{2A6D}",
    '&conint;'			=>	"\x{222E}",
    '&coprod;'			=>	"\x{2210}",
    '&copy;'			=>	"\x{00A9}",
    '&copysr;'			=>	"\x{2117}",
    '&cross;'			=>	"\x{2717}",
    '&csub;'			=>	"\x{2ACF}",
    '&csube;'			=>	"\x{2AD1}",
    '&csup;'			=>	"\x{2AD0}",
    '&csupe;'			=>	"\x{2AD2}",
    '&ctdot;'			=>	"\x{22EF}",
    '&ctee;'			=>	"\x{0063}\x{0318}",
    '&ctilde;'			=>	"\x{0063}\x{0303}",
    '&ctlig;'			=>	"\x{0063}\x{0074}",
    '&cudarrl;'			=>	"\x{2938}",
    '&cudarrr;'			=>	"\x{2935}",
    '&cuepr;'			=>	"\x{22DE}",
    '&cuesc;'			=>	"\x{22DF}",
    '&cularr;'			=>	"\x{21B6}",
    '&cularrp;'			=>	"\x{293D}",
    '&cup;'			=>	"\x{222A}",
    '&cupbrcap;'		=>	"\x{2A48}",
    '&cupcap;'			=>	"\x{2A46}",
    '&cupcup;'			=>	"\x{2A4A}",
    '&cupdot;'			=>	"\x{228D}",
    '&cupor;'			=>	"\x{2A45}",
    '&cups;'			=>	"\x{222A}",
    '&curarr;'			=>	"\x{21B7}",
    '&curarrm;'			=>	"\x{293C}",
    '&curl;'			=>	"\x{031B}",
    '&curlyeqprec;'		=>	"\x{22DE}",
    '&curlyeqsucc;'		=>	"\x{22DF}",
    '&curlyvee;'		=>	"\x{22CE}",
    '&curlywedge;'		=>	"\x{22CF}",
    '&curren;'			=>	"\x{00A4}",
    '&curvearrowleft;'		=>	"\x{21B6}",
    '&curvearrowright;'		=>	"\x{21B7}",
    '&cuvee;'			=>	"\x{22CE}",
    '&cuwed;'			=>	"\x{22CF}",
    '&cwconint;'		=>	"\x{2232}",
    '&cwint;'			=>	"\x{2231}",
    '&cylcty;'			=>	"\x{232D}",
    '&dArr;'			=>	"\x{21D3}",
    '&dHar;'			=>	"\x{2965}",
    '&dagger;'			=>	"\x{2020}",
    '&dagger;'			=>	"\x{2020}",
    '&dagger2;'			=>	"\x{2021}",
    '&daleth;'			=>	"\x{2138}",
    '&darr;'			=>	"\x{2193}",
    '&dash;'			=>	"\x{2010}",
    '&dashv;'			=>	"\x{22A3}",
    '&dbar;'			=>	"\x{0064}\x{0304}",
    '&dbkarow;'			=>	"\x{290F}",
    '&dcaron;'			=>	"\x{010F}",
    '&dcy;'			=>	"\x{0434}",
    '&dd;'			=>	"\x{2146}",
    '&ddagger;'			=>	"\x{2021}",
    '&ddarr;'			=>	"\x{21CA}",
    '&ddash;'			=>	"\x{00F0}",
    '&ddotseq;'			=>	"\x{2A77}",
    '&deg;'			=>	"\x{00B0}",
    '&degree;'			=>	"\x{B0}",
    '&delta;'			=>	"\x{03B4}",
    '&demptyv;'			=>	"\x{29B1}",
    '&dfisht;'			=>	"\x{297F}",
    '&dgr;'			=>	"\x{03B4}",
    '&dgr;'			=>	"\x{03B4}",
    '&dharl;'			=>	"\x{21C3}",
    '&dharr;'			=>	"\x{21C2}",
    '&diam;'			=>	"\x{22C4}",
    '&diamond;'			=>	"\x{22C4}",
    '&diamondsuit;'		=>	"\x{2666}",
    '&diams;'			=>	"\x{2666}",
    '&digamma;'			=>	"\x{03DD}",
    '&disin;'			=>	"\x{22F2}",
    '&div;'			=>	"\x{00F7}",
    '&divide;'			=>	"\x{00F7}",
    '&divideontimes;'		=>	"\x{22C7}",
    '&divonx;'			=>	"\x{22C7}",
    '&djcy;'			=>	"\x{0452}",
    '&dlcorn;'			=>	"\x{231E}",
    '&dlcrop;'			=>	"\x{230D}",
    '&dollar;'			=>	"\x{0024}",
    '&dotb;'			=>	"\x{0323}",
    '&doteq;'			=>	"\x{2250}",
    '&doteqdot;'		=>	"\x{2251}",
    '&dotminus;'		=>	"\x{2238}",
    '&dotplus;'			=>	"\x{2214}",
    '&dotsquare;'		=>	"\x{22A1}",
    '&doublebarwedge;'		=>	"\x{2306}",
    '&downarrow;'		=>	"\x{2193}",
    '&downdownarrows;'		=>	"\x{21CA}",
    '&downharpoonleft;'		=>	"\x{21C3}",
    '&downharpoonright;'	=>	"\x{21C2}",
    '&drbkarow;'		=>	"\x{2910}",
    '&drcorn;'			=>	"\x{231F}",
    '&drcrop;'			=>	"\x{230C}",
    '&dscy;'			=>	"\x{0455}",
    '&dsol;'			=>	"\x{29F6}",
    '&dstrok;'			=>	"\x{0111}",
    '&dtail;'			=>	"\x{0064}\x{031B}",
    '&dtdot;'			=>	"\x{22F1}",
    '&dtri;'			=>	"\x{25BF}",
    '&dtrif;'			=>	"\x{25BE}",
    '&duarr;'			=>	"\x{21F5}",
    '&duhar;'			=>	"\x{296F}",
    '&dwangle;'			=>	"\x{29A6}",
    '&dzcy;'			=>	"\x{045F}",
    '&dzigrarr;'		=>	"\x{27FF}",
    '&eDDot;'			=>	"\x{2A77}",
    '&eDot;'			=>	"\x{2251}",
    '&eacgr;'			=>	"\x{03AD}",
    '&eacgr;'			=>	"\x{1F73}",
    '&eacugr;'			=>	"\x{1F73}",
    '&eacute;'			=>	"\x{00E9}",
    '&easter;'			=>	"\x{2A6E}",
    '&ebar;'			=>	"\x{0113}",
    '&ebreve;'			=>	"\x{0115}",
    '&ecaron;'			=>	"\x{011B}",
    '&ecedil;'			=>	"\x{0065}\x{0327}",
    '&ecir;'			=>	"\x{2256}",
    '&ecirc;'			=>	"\x{00EA}",
    '&ecirgr;'			=>	"\x{03B5}\x{1FC0}",
    '&ecolon;'			=>	"\x{2255}",
    '&ecy;'			=>	"\x{044D}",
    '&edot;'			=>	"\x{0117}",
    '&ee;'			=>	"\x{2147}",
    '&eeacgr;'			=>	"\x{03AE}",
    '&eeacgr;'			=>	"\x{1F75}",
    '&eeacugr;'			=>	"\x{1F75}",
    '&eeaigr;'			=>	"\x{1FC4}",
    '&eecigr;'			=>	"\x{1FC7}",
    '&eecirgr;'			=>	"\x{1FC6}",
    '&eegigr;'			=>	"\x{1FC2}",
    '&eegr;'			=>	"\x{03B7}",
    '&eegr;'			=>	"\x{03B7}",
    '&eegragr;'			=>	"\x{1F74}",
    '&eegvgr;'			=>	"\x{1F74}",
    '&eeigr;'			=>	"\x{1FC3}",
    '&eeiotgr;'			=>	"\x{1FC3}",
    '&eeragr;'			=>	"\x{1F25}",
    '&eeraigr;'			=>	"\x{1F95}",
    '&eercgr;'			=>	"\x{1F26}",
    '&eercigr;'			=>	"\x{1F96}",
    '&eerggr;'			=>	"\x{1F23}",
    '&eergigr;'			=>	"\x{1F93}",
    '&eerigr;'			=>	"\x{1F91}",
    '&eerougr;'			=>	"\x{1F21}",
    '&eesagr;'			=>	"\x{1F24}",
    '&eesaigr;'			=>	"\x{1F94}",
    '&eescgr;'			=>	"\x{1F26}",
    '&eescigr;'			=>	"\x{1F96}",
    '&eesggr;'			=>	"\x{1F22}",
    '&eesgigr;'			=>	"\x{1F92}",
    '&eesigr;'			=>	"\x{1F90}",
    '&eesmogr;'			=>	"\x{1F20}",
    '&eetigr;'			=>	"\x{03B7}\x{0342}",
    '&eetigr1;'			=>	"\x{1FC6}",
    '&efDot;'			=>	"\x{2252}",
    '&eg;'			=>	"\x{2A9A}",
    '&egr;'			=>	"\x{03B5}",
    '&egr;'			=>	"\x{03B5}",
    '&egragr;'			=>	"\x{1F72}",
    '&egrave;'			=>	"\x{00E8}",
    '&egs;'			=>	"\x{2A96}",
    '&egsdot;'			=>	"\x{2A98}",
    '&egvgr;'			=>	"\x{1F72}",
    '&el;'			=>	"\x{2A99}",
    '&elinters;'		=>	"\x{FFFD}",
    '&ell;'			=>	"\x{2113}",
    '&els;'			=>	"\x{2A95}",
    '&elsdot;'			=>	"\x{2A97}",
    '&emacr;'			=>	"\x{0113}",
    '&empty;'			=>	"\x{2205}",
    '&emptyset;'		=>	"\x{2205}",
    '&emptyv;'			=>	"\x{2205}",
    '&emsp;'			=>	"\x{2003}",
    '&emsp13;'			=>	"\x{2004}",
    '&emsp14;'			=>	"\x{2005}",
    '&eng;'			=>	"\x{014B}",
    '&ensp;'			=>	"\x{2002}",
    '&eogon;'			=>	"\x{0119}",
    '&epar;'			=>	"\x{22D5}",
    '&eparsl;'			=>	"\x{29E3}",
    '&eplus;'			=>	"\x{2A71}",
    '&epsi;'			=>	"\x{03B5}",
    '&epsiv;'			=>	"\x{025B}",
    '&eqcirc;'			=>	"\x{2256}",
    '&eqcolon;'			=>	"\x{2255}",
    '&eqsim;'			=>	"\x{2242}",
    '&eqslantgtr;'		=>	"\x{2A96}",
    '&eqslantless;'		=>	"\x{2A95}",
    '&equals;'			=>	"\x{003D}",
    '&equest;'			=>	"\x{225F}",
    '&equiv;'			=>	"\x{2261}",
    '&equivDD;'			=>	"\x{2A78}",
    '&eqvparsl;'		=>	"\x{29E5}",
    '&erDot;'			=>	"\x{2253}",
    '&eragr;'			=>	"\x{1F14}",
    '&erarr;'			=>	"\x{2971}",
    '&erggr;'			=>	"\x{1F13}",
    '&erougr;'			=>	"\x{1F11}",
    '&es;'			=>	"\x{031B}",
    '&esagr;'			=>	"\x{1F14}",
    '&esdot;'			=>	"\x{2250}",
    '&esggr;'			=>	"\x{1F12}",
    '&eshort;'			=>	"\x{0115}",
    '&esim;'			=>	"\x{2242}",
    '&esmogr;'			=>	"\x{1F10}",
    '&esset;'			=>	"\x{00DF}",
    '&eta;'			=>	"\x{03B7}",
    '&etail;'			=>	"\x{0065}\x{031B}",
    '&eth;'			=>	"\x{00F0}",
    '&etigr;'			=>	"\x{03B5}",
    '&etilde;'			=>	"\x{0065}\x{0303}",
    '&euml;'			=>	"\x{00EB}",
    '&excl;'			=>	"\x{0021}",
    '&exist;'			=>	"\x{2203}",
    '&expectation;'		=>	"\x{2130}",
    '&exponentiale;'		=>	"\x{2147}",
    '&fallingdotseq;'		=>	"\x{2252}",
    '&fcy;'			=>	"\x{0444}",
    '&female;'			=>	"\x{2640}",
    '&ffilig;'			=>	"\x{FB03}",
    '&fflig;'			=>	"\x{FB00}",
    '&ffllig;'			=>	"\x{FB04}",
    '&filig;'			=>	"\x{FB01}",
    '&flat;'			=>	"\x{266D}",
    '&fleur;'			=>	"\x{269c}",
    '&fllig;'			=>	"\x{FB02}",
    '&fltns;'			=>	"\x{25B1}",
    '&fnof;'			=>	"\x{0192}",
    '&forall;'			=>	"\x{2200}",
    '&fork;'			=>	"\x{22D4}",
    '&forkv;'			=>	"\x{2AD9}",
    '&fpartint;'		=>	"\x{2A0D}",
    '&frac12;'			=>	"\x{00BD}",
    '&frac13;'			=>	"\x{2153}",
    '&frac14;'			=>	"\x{00BC}",
    '&frac15;'			=>	"\x{2155}",
    '&frac16;'			=>	"\x{2159}",
    '&frac18;'			=>	"\x{215B}",
    '&frac23;'			=>	"\x{2154}",
    '&frac25;'			=>	"\x{2156}",
    '&frac34;'			=>	"\x{00BE}",
    '&frac35;'			=>	"\x{2157}",
    '&frac38;'			=>	"\x{215C}",
    '&frac45;'			=>	"\x{2158}",
    '&frac56;'			=>	"\x{215A}",
    '&frac58;'			=>	"\x{215D}",
    '&frac78;'			=>	"\x{215E}",
    '&frown;'			=>	"\x{2322}",
    '&ftee;'			=>	"\x{0066}\x{0318}",
    '&gE;'			=>	"\x{2267}",
    '&gEl;'			=>	"\x{2A8C}",
    '&gacute;'			=>	"\x{01F5}",
    '&gamma;'			=>	"\x{03B3}",
    '&gammad;'			=>	"\x{03DD}",
    '&gap;'			=>	"\x{2A86}",
    '&gbreve;'			=>	"\x{011F}",
    '&gcirc;'			=>	"\x{011D}",
    '&gcy;'			=>	"\x{0433}",
    '&gdgr;'			=>	"\x{1FED}",
    '&gdot;'			=>	"\x{0121}",
    '&ge;'			=>	"\x{2265}",
    '&gel;'			=>	"\x{22DB}",
    '&geq;'			=>	"\x{2265}",
    '&geqq;'			=>	"\x{2267}",
    '&geqslant;'		=>	"\x{2A7E}",
    '&ges;'			=>	"\x{2A7E}",
    '&gescc;'			=>	"\x{2AA9}",
    '&gesdot;'			=>	"\x{2A80}",
    '&gesdoto;'			=>	"\x{2A82}",
    '&gesdotol;'		=>	"\x{2A84}",
    '&gesl;'			=>	"\x{22DB}",
    '&gesles;'			=>	"\x{2A94}",
    '&gg;'			=>	"\x{226B}",
    '&ggg;'			=>	"\x{22D9}",
    '&ggr;'			=>	"\x{03B3}",
    '&ggr;'			=>	"\x{03B3}",
    '&gimel;'			=>	"\x{2137}",
    '&gjcy;'			=>	"\x{0453}",
    '&gl;'			=>	"\x{2277}",
    '&glE;'			=>	"\x{2A92}",
    '&gla;'			=>	"\x{2AA5}",
    '&glj;'			=>	"\x{2AA4}",
    '&gnE;'			=>	"\x{2269}",
    '&gnap;'			=>	"\x{2A8A}",
    '&gnapprox;'		=>	"\x{2A8A}",
    '&gne;'			=>	"\x{2A88}",
    '&gneq;'			=>	"\x{2A88}",
    '&gneqq;'			=>	"\x{2269}",
    '&gnsim;'			=>	"\x{22E7}",
    '&grA;'			=>	"\x{0391}",
    '&grAs;'			=>	"\x{1F08}",
    '&grB;'			=>	"\x{0392}",
    '&grC;'			=>	"\x{039E}",
    '&grD;'			=>	"\x{0394}",
    '&grE;'			=>	"\x{0395}",
    '&grF;'			=>	"\x{03A6}",
    '&grG;'			=>	"\x{0393}",
    '&grH;'			=>	"\x{0397}",
    '&grI;'			=>	"\x{0399}",
    '&grK;'			=>	"\x{039A}",
    '&grL;'			=>	"\x{039B}",
    '&grM;'			=>	"\x{039C}",
    '&grN;'			=>	"\x{039D}",
    '&grO;'			=>	"\x{039F}",
    '&grP;'			=>	"\x{03A0}",
    '&grQ;'			=>	"\x{0398}",
    '&grR;'			=>	"\x{03A1}",
    '&grS;'			=>	"\x{03A3}",
    '&grST;'			=>	"\x{03A3}",
    '&grT;'			=>	"\x{03A4}",
    '&grU;'			=>	"\x{03A5}",
    '&grV;'			=>	"\x{3DC}",
    '&grW;'			=>	"\x{03A9}",
    '&grX;'			=>	"\x{03A7}",
    '&grY;'			=>	"\x{03A8}",
    '&grZ;'			=>	"\x{0396}",
    '&gra;'			=>	"\x{03B1}",
    '&graa;'			=>	"\x{1F7D}",
    '&graad;'			=>	"\x{1F71}",
    '&grac;'			=>	"\x{1FB6}",
    '&gracd;'			=>	"\x{1FB6}",
    '&graci;'			=>	"\x{1FB7}",
    '&gracs;'			=>	"\x{1F06}",
    '&grad;'			=>	"\x{03B1}",
    '&gradc;'			=>	"\x{1FB6}",
    '&grag;'			=>	"\x{1F70}",
    '&gragr;'			=>	"\x{1FEF}",
    '&grai;'			=>	"\x{1FB3}",
    '&graia;'			=>	"\x{1FB4}",
    '&graic;'			=>	"\x{1FB7}",
    '&grais;'			=>	"\x{1F80}",
    '&graisa;'			=>	"\x{1F84}",
    '&grap;'			=>	"\x{1FBD}",
    '&grar;'			=>	"\x{1F01}",
    '&grara;'			=>	"\x{1F04}",
    '&grarg;'			=>	"\x{1F03}",
    '&gras;'			=>	"\x{1F00}",
    '&grasa;'			=>	"\x{1F04}",
    '&grasad;'			=>	"\x{1F04}",
    '&grasc;'			=>	"\x{1F06}",
    '&grasci;'			=>	"\x{1F86}",
    '&grasd;'			=>	"\x{1F00}",
    '&grasg;'			=>	"\x{1F02}",
    '&grasi;'			=>	"\x{1F80}",
    '&grasia;'			=>	"\x{1F84}",
    '&grat;'			=>	"\x{1FB6}",
    '&grb;'			=>	"\x{03B2}",
    '&grc;'			=>	"\x{03BE}",
    '&grcolon;'			=>	"\x{00B7}",
    '&grd;'			=>	"\x{03B4}",
    '&gre;'			=>	"\x{03B5}",
    '&grea;'			=>	"\x{1F73}",
    '&gread;'			=>	"\x{1F73}",
    '&grec;'			=>	"\x{03B5}\x{1FC0}",
    '&grecs;'			=>	"\x{1F10}\x{1FC0}",
    '&gred;'			=>	"\x{03B5}",
    '&greda;'			=>	"\x{1F73}",
    '&gredg;'			=>	"\x{1F72}",
    '&greg;'			=>	"\x{1F72}",
    '&grei;'			=>	"\x{03B5}",
    '&grer;'			=>	"\x{1F11}",
    '&grera;'			=>	"\x{1F15}",
    '&grerg;'			=>	"\x{1F13}",
    '&gres;'			=>	"\x{1F10}",
    '&gresa;'			=>	"\x{1F14}",
    '&gresad;'			=>	"\x{1F14}",
    '&gresc;'			=>	"\x{1F10}\x{1FC0}",
    '&gresg;'			=>	"\x{1F12}",
    '&grf;'			=>	"\x{03C8}",
    '&grg;'			=>	"\x{03A5}",
    '&grh;'			=>	"\x{03B7}",
    '&grha;'			=>	"\x{1F75}",
    '&grhai;'			=>	"\x{1FC4}",
    '&grhc;'			=>	"\x{1FC6}",
    '&grhcd;'			=>	"\x{1FC6}",
    '&grhci;'			=>	"\x{1FC7}",
    '&grhcr;'			=>	"\x{1F27}",
    '&grhcri;'			=>	"\x{1F97}",
    '&grhcs;'			=>	"\x{1F26}",
    '&grhd;'			=>	"\x{03B7}",
    '&grhg;'			=>	"\x{1F74}",
    '&grhgd;'			=>	"\x{1F74}",
    '&grhi;'			=>	"\x{1FC3}",
    '&grhia;'			=>	"\x{1FC4}",
    '&grhic;'			=>	"\x{1FC7}",
    '&grhicr;'			=>	"\x{1F97}",
    '&grhid;'			=>	"\x{1FC3}",
    '&grhig;'			=>	"\x{1FC2}",
    '&grhisc;'			=>	"\x{1F96}",
    '&grhr;'			=>	"\x{1F21}",
    '&grhra;'			=>	"\x{1F25}",
    '&grhrc;'			=>	"\x{1F27}",
    '&grhrci;'			=>	"\x{1F97}",
    '&grhrd;'			=>	"\x{1F21}",
    '&grhrg;'			=>	"\x{1F23}",
    '&grhric;'			=>	"\x{1F97}",
    '&grhrt;'			=>	"\x{1F27}",
    '&grhs;'			=>	"\x{1F20}",
    '&grhsa;'			=>	"\x{1F24}",
    '&grhsai;'			=>	"\x{1F94}",
    '&grhsc;'			=>	"\x{1F26}",
    '&grhsci;'			=>	"\x{1F96}",
    '&grhsg;'			=>	"\x{1F22}",
    '&grhsi;'			=>	"\x{1F90}",
    '&grhst;'			=>	"\x{1F26}",
    '&grht;'			=>	"\x{1FC6}",
    '&gri;'			=>	"\x{03B9}",
    '&gria;'			=>	"\x{1F77}",
    '&griad;'			=>	"\x{1FD3}",
    '&gric;'			=>	"\x{1FD6}",
    '&gricr;'			=>	"\x{1F37}",
    '&grics;'			=>	"\x{1F36}",
    '&grid;'			=>	"\x{03CA}",
    '&grida;'			=>	"\x{1FD3}",
    '&gridg;'			=>	"\x{1FD2}",
    '&grig;'			=>	"\x{1F76}",
    '&grir;'			=>	"\x{1F31}",
    '&grira;'			=>	"\x{1F35}",
    '&grirc;'			=>	"\x{1F37}",
    '&grirg;'			=>	"\x{1F33}",
    '&gris;'			=>	"\x{1F30}",
    '&grisa;'			=>	"\x{1F34}",
    '&grisc;'			=>	"\x{1F36}",
    '&grisd;'			=>	"\x{1F30}",
    '&grisg;'			=>	"\x{1F32}",
    '&grit;'			=>	"\x{1FD6}",
    '&grk;'			=>	"\x{03C7}",
    '&grl;'			=>	"\x{03BB}",
    '&grm;'			=>	"\x{03BC}",
    '&grn;'			=>	"\x{03C5}",
    '&gro;'			=>	"\x{03BF}",
    '&groa;'			=>	"\x{1F79}",
    '&groad;'			=>	"\x{1F79}",
    '&groc;'			=>	"\x{03BF}\x{1FC0}",
    '&grod;'			=>	"\x{03BF}",
    '&grog;'			=>	"\x{1F78}",
    '&grogd;'			=>	"\x{1F78}",
    '&groi;'			=>	"\x{03BF}",
    '&gror;'			=>	"\x{1F41}",
    '&grora;'			=>	"\x{1F45}",
    '&grorc;'			=>	"\x{1F41}\x{FC0}",
    '&grorg;'			=>	"\x{1F43}",
    '&gros;'			=>	"\x{1F40}",
    '&grosa;'			=>	"\x{1F44}",
    '&grosc;'			=>	"\x{1F40}\x{FC0}",
    '&grosdc;'			=>	"\x{1F40}\x{1FC0}",
    '&grosg;'			=>	"\x{1F42}",
    '&grot;'			=>	"\x{03BF}\x{0342}",
    '&grp;'			=>	"\x{03C0}",
    '&grq;'			=>	"\x{03B8}",
    '&grqu;'			=>	"\x{1FF3}",
    '&grr;'			=>	"\x{03C1}",
    '&grra;'			=>	"\x{03C1}\x{1FFD}",
    '&grrg;'			=>	"\x{03C1}\x{1FEF}",
    '&grrr;'			=>	"\x{1FE5}",
    '&grrra;'			=>	"\x{1FE5}\x{1FBD}",
    '&grrrg;'			=>	"\x{1FE5}\x{1FEF}",
    '&grrs;'			=>	"\x{1FE4}",
    '&grs;'			=>	"\x{03C3}",
    '&grst;'			=>	"\x{03C2}",
    '&grt;'			=>	"\x{03C4}",
    '&gru;'			=>	"\x{03C5}",
    '&grua;'			=>	"\x{1F7B}",
    '&gruad;'			=>	"\x{1FE3}",
    '&gruc;'			=>	"\x{1FE6}",
    '&grucr;'			=>	"\x{1F57}",
    '&grucs;'			=>	"\x{1F56}",
    '&grud;'			=>	"\x{03CB}",
    '&gruda;'			=>	"\x{1FE3}",
    '&grug;'			=>	"\x{1F7A}",
    '&grui;'			=>	"\x{03C5}",
    '&grur;'			=>	"\x{1F51}",
    '&grura;'			=>	"\x{1F55}",
    '&grurc;'			=>	"\x{1F57}",
    '&grurdc;'			=>	"\x{1F57}",
    '&grurg;'			=>	"\x{1F53}",
    '&grurt;'			=>	"\x{1F57}",
    '&grus;'			=>	"\x{1F50}",
    '&grusa;'			=>	"\x{1F54}",
    '&grusc;'			=>	"\x{1F56}",
    '&grusg;'			=>	"\x{1F53}",
    '&grust;'			=>	"\x{1F56}",
    '&grut;'			=>	"\x{1FE6}",
    '&grv;'			=>	"\x{3DD}",
    '&grw;'			=>	"\x{03C9}",
    '&grwa;'			=>	"\x{1F7D}",
    '&grwac;'			=>	"\x{1F7D}\x{1FC0}",
    '&grwad;'			=>	"\x{1F7D}",
    '&grwai;'			=>	"\x{1FF4}",
    '&grwc;'			=>	"\x{1FF6}",
    '&grwcd;'			=>	"\x{1FF6}",
    '&grwci;'			=>	"\x{1FF7}",
    '&grwcs;'			=>	"\x{1F66}",
    '&grwd;'			=>	"\x{03C9}",
    '&grwdc;'			=>	"\x{1FF6}",
    '&grwdg;'			=>	"\x{1F7C}",
    '&grwg;'			=>	"\x{1F7C}",
    '&grwgi;'			=>	"\x{1FF2}",
    '&grwi;'			=>	"\x{1FF3}",
    '&grwia;'			=>	"\x{1FF4}",
    '&grwic;'			=>	"\x{1FF7}",
    '&grwirc;'			=>	"\x{1FA7}",
    '&grwis;'			=>	"\x{1FA0}",
    '&grwit;'			=>	"\x{1FF7}",
    '&grwr;'			=>	"\x{1F61}",
    '&grwra;'			=>	"\x{1F65}",
    '&grwrc;'			=>	"\x{1F67}",
    '&grwrd;'			=>	"\x{1F61}",
    '&grwrg;'			=>	"\x{1F63}",
    '&grws;'			=>	"\x{1F60}",
    '&grwsa;'			=>	"\x{1F64}",
    '&grwsai;'			=>	"\x{1FA4}",
    '&grwsc;'			=>	"\x{1F66}",
    '&grwsg;'			=>	"\x{1F63}",
    '&grwt;'			=>	"\x{1FF6}",
    '&grx;'			=>	"\x{03A7}",
    '&gry;'			=>	"\x{03A8}",
    '&grz;'			=>	"\x{03B6}",
    '&gsim;'			=>	"\x{2273}",
    '&gsime;'			=>	"\x{2A8E}",
    '&gsiml;'			=>	"\x{2A90}",
    '&gt;'			=>	"\x{003E}",
    '&gtail;'			=>	"\x{0067}\x{031B}",
    '&gtcc;'			=>	"\x{2AA7}",
    '&gtcir;'			=>	"\x{2A7A}",
    '&gtdot;'			=>	"\x{22D7}",
    '&gtee;'			=>	"\x{0067}\x{0318}",
    '&gtlPar;'			=>	"\x{2995}",
    '&gtquest;'			=>	"\x{2A7C}",
    '&gtrapprox;'		=>	"\x{2A86}",
    '&gtrarr;'			=>	"\x{2978}",
    '&gtrdot;'			=>	"\x{22D7}",
    '&gtreqless;'		=>	"\x{22DB}",
    '&gtreqqless;'		=>	"\x{2A8C}",
    '&gtrless;'			=>	"\x{2277}",
    '&gtrsim;'			=>	"\x{2273}",
    '&gvertneqq;'		=>	"\x{2269}",
    '&gvnE;'			=>	"\x{2269}",
    '&hArr;'			=>	"\x{21D4}",
    '&hairsp;'			=>	"\x{200A}",
    '&half;'			=>	"\x{00BD}",
    '&hamilt;'			=>	"\x{210B}",
    '&hardcy;'			=>	"\x{044A}",
    '&harr;'			=>	"\x{2194}",
    '&harrcir;'			=>	"\x{2948}",
    '&harrw;'			=>	"\x{21AD}",
    '&hbar;'			=>	"\x{210F}",
    '&hcirc;'			=>	"\x{0125}",
    '&hdot;'			=>	"\x{1E25}",
    '&hearts;'			=>	"\x{2665}",
    '&heartsuit;'		=>	"\x{2665}",
    '&hellip;'			=>	"\x{2026}",
    '&hercon;'			=>	"\x{22B9}",
    '&hksearow;'		=>	"\x{2925}",
    '&hkswarow;'		=>	"\x{2926}",
    '&hoarr;'			=>	"\x{21FF}",
    '&homtht;'			=>	"\x{223B}",
    '&hookleftarrow;'		=>	"\x{21A9}",
    '&hookrightarrow;'		=>	"\x{21AA}",
    '&horbar;'			=>	"\x{2015}",
    '&hslash;'			=>	"\x{210F}",
    '&hstrok;'			=>	"\x{0127}",
    '&hybull;'			=>	"\x{2043}",
    '&hyphen;'			=>	"\x{2010}",
    '&hyphgr;'			=>	"\x{1FD3}",
    '&iacdiagr;'		=>	"\x{1FD3}",
    '&iacgr;'			=>	"\x{03AF}",
    '&iacgr;'			=>	"\x{1F77}",
    '&iacugr;'			=>	"\x{1F77}",
    '&iacute;'			=>	"\x{00ED}",
    '&iadgr;'			=>	"\x{1FD3}",
    '&ibar;'			=>	"\x{012B}",
    '&ic;'			=>	"\x{2063}",
    '&icirc;'			=>	"\x{00EE}",
    '&icirgr;'			=>	"\x{1FD6}",
    '&icy;'			=>	"\x{0438}",
    '&idiagr;'			=>	"\x{0390}",
    '&idiagr;'			=>	"\x{03CA}",
    '&idiagvgr;'		=>	"\x{1FD2}",
    '&idigr;'			=>	"\x{03CA}",
    '&idigr;'			=>	"\x{03CA}",
    '&iecy;'			=>	"\x{0435}",
    '&iexcl;'			=>	"\x{00A1}",
    '&iexcla;'			=>	"\x{00A1}",
    '&iff;'			=>	"\x{21D4}",
    '&igdgr;'			=>	"\x{1FD2}",
    '&igr;'			=>	"\x{03B9}",
    '&igr;'			=>	"\x{03B9}",
    '&igragr;'			=>	"\x{1F76}",
    '&igrave;'			=>	"\x{00EC}",
    '&igvgr;'			=>	"\x{1F76}",
    '&ihacek;'			=>	"\x{0069}\x{030C}",
    '&ii;'			=>	"\x{2148}",
    '&iiiint;'			=>	"\x{2A0C}",
    '&iiint;'			=>	"\x{222D}",
    '&iinfin;'			=>	"\x{29DC}",
    '&iiota;'			=>	"\x{2129}",
    '&ijlig;'			=>	"\x{0133}",
    '&imacr;'			=>	"\x{012B}",
    '&image;'			=>	"\x{2111}",
    '&imagline;'		=>	"\x{2110}",
    '&imagpart;'		=>	"\x{2111}",
    '&imath;'			=>	"\x{0131}",
    '&imof;'			=>	"\x{22B7}",
    '&imped;'			=>	"\x{01B5}",
    '&in;'			=>	"\x{2208}",
    '&incare;'			=>	"\x{2105}",
    '&infin;'			=>	"\x{221E}",
    '&infintie;'		=>	"\x{29DD}",
    '&inodot;'			=>	"\x{0131}",
    '&int;'			=>	"\x{222B}",
    '&intcal;'			=>	"\x{22BA}",
    '&integers;'		=>	"\x{2124}",
    '&intercal;'		=>	"\x{22BA}",
    '&intlarhk;'		=>	"\x{2A17}",
    '&intprod;'			=>	"\x{2A3C}",
    '&iocy;'			=>	"\x{0451}",
    '&iogon;'			=>	"\x{012F}",
    '&iota;'			=>	"\x{03B9}",
    '&iprod;'			=>	"\x{2A3C}",
    '&iquest;'			=>	"\x{00BF}",
    '&iragr;'			=>	"\x{1F35}",
    '&ircgr;'			=>	"\x{1F37}",
    '&irggr;'			=>	"\x{1F33}",
    '&irougr;'			=>	"\x{1F31}",
    '&isagr;'			=>	"\x{1F34}",
    '&iscgr;'			=>	"\x{1F36}",
    '&isggr;'			=>	"\x{1F32}",
    '&ishort;'			=>	"\x{012D}",
    '&isin;'			=>	"\x{2208}",
    '&isinE;'			=>	"\x{22F9}",
    '&isindot;'			=>	"\x{22F5}",
    '&isins;'			=>	"\x{22F4}",
    '&isinsv;'			=>	"\x{22F3}",
    '&isinv;'			=>	"\x{2208}",
    '&ismogr;'			=>	"\x{1F30}",
    '&isubgr;'			=>	"\x{037A}",
    '&it;'			=>	"\x{2062}",
    '&itigr;'			=>	"\x{1FD6}",
    '&itilde;'			=>	"\x{0129}",
    '&iukcy;'			=>	"\x{0456}",
    '&iuml;'			=>	"\x{00EF}",
    '&jcirc;'			=>	"\x{0135}",
    '&jcy;'			=>	"\x{0439}",
    '&jmath;'			=>	"\x{006A}",
    '&jsercy;'			=>	"\x{0458}",
    '&jtilde;'			=>	"\x{006A}\x{0303}",
    '&jukcy;'			=>	"\x{0454}",
    '&kappa;'			=>	"\x{03BA}",
    '&kappav;'			=>	"\x{03F0}",
    '&kcedil;'			=>	"\x{0137}",
    '&kcy;'			=>	"\x{043A}",
    '&kgr;'			=>	"\x{03BA}",
    '&kgr;'			=>	"\x{03C7}",
    '&kgreen;'			=>	"\x{0138}",
    '&khcy;'			=>	"\x{0445}",
    '&khgr;'			=>	"\x{03A7}",
    '&khgr;'			=>	"\x{03C7}",
    '&kjcy;'			=>	"\x{045C}",
    '&ktee;'			=>	"\x{006B}\x{0318}",
    '&lAarr;'			=>	"\x{21DA}",
    '&lArr;'			=>	"\x{21D0}",
    '&lAtail;'			=>	"\x{291B}",
    '&lBarr;'			=>	"\x{290E}",
    '&lE;'			=>	"\x{2266}",
    '&lEg;'			=>	"\x{2A8B}",
    '&lHar;'			=>	"\x{2962}",
    '&labr;'			=>	"\x{3008}",
    '&lacute;'			=>	"\x{013A}",
    '&laemptyv;'		=>	"\x{29B4}",
    '&lagran;'			=>	"\x{2112}",
    '&lambda;'			=>	"\x{03BB}",
    '&lang;'			=>	"\x{2329}",
    '&langd;'			=>	"\x{2991}",
    '&langle;'			=>	"\x{2329}",
    '&lap;'			=>	"\x{2A85}",
    '&laquo;'			=>	"\x{00AB}",
    '&larr;'			=>	"\x{2190}",
    '&larrb;'			=>	"\x{21E4}",
    '&larrbfs;'			=>	"\x{291F}",
    '&larrfs;'			=>	"\x{291D}",
    '&larrhk;'			=>	"\x{21A9}",
    '&larrlp;'			=>	"\x{21AB}",
    '&larrpl;'			=>	"\x{2939}",
    '&larrsim;'			=>	"\x{2973}",
    '&larrtl;'			=>	"\x{21A2}",
    '&lat;'			=>	"\x{2AAB}",
    '&latail;'			=>	"\x{2919}",
    '&late;'			=>	"\x{2AAD}",
    '&lates;'			=>	"\x{2AAD}",
    '&lbar;'			=>	"\x{019A}",
    '&lbarr;'			=>	"\x{290C}",
    '&lbbrk;'			=>	"\x{3014}",
    '&lbrace;'			=>	"\x{007B}",
    '&lbrack;'			=>	"\x{005B}",
    '&lbrke;'			=>	"\x{298B}",
    '&lbrksld;'			=>	"\x{298F}",
    '&lbrkslu;'			=>	"\x{298D}",
    '&lcaron;'			=>	"\x{013E}",
    '&lcedil;'			=>	"\x{013C}",
    '&lceil;'			=>	"\x{2308}",
    '&lcub;'			=>	"\x{007B}",
    '&lcy;'			=>	"\x{043B}",
    '&ldca;'			=>	"\x{2936}",
    '&ldquo;'			=>	"\x{201C}",
    '&ldquor;'			=>	"\x{201E}",
    '&ldrdhar;'			=>	"\x{2967}",
    '&ldrushar;'		=>	"\x{294B}",
    '&ldsh;'			=>	"\x{21B2}",
    '&le;'			=>	"\x{2264}",
    '&leftarrow;'		=>	"\x{2190}",
    '&leftarrowtail;'		=>	"\x{21A2}",
    '&leftharpoondown;'		=>	"\x{21BD}",
    '&leftharpoonup;'		=>	"\x{21BC}",
    '&leftleftarrows;'		=>	"\x{21C7}",
    '&leftrightarrow;'		=>	"\x{2194}",
    '&leftrightarrows;'		=>	"\x{21C6}",
    '&leftrightharpoons;'	=>	"\x{21CB}",
    '&leftrightsquigarrow;'	=>	"\x{21AD}",
    '&leftthreetimes;'		=>	"\x{22CB}",
    '&leg;'			=>	"\x{22DA}",
    '&leq;'			=>	"\x{2264}",
    '&leqq;'			=>	"\x{2266}",
    '&leqslant;'		=>	"\x{2A7D}",
    '&les;'			=>	"\x{2A7D}",
    '&lescc;'			=>	"\x{2AA8}",
    '&lesdot;'			=>	"\x{2A7F}",
    '&lesdoto;'			=>	"\x{2A81}",
    '&lesdotor;'		=>	"\x{2A83}",
    '&lesg;'			=>	"\x{22DA}",
    '&lesges;'			=>	"\x{2A93}",
    '&lessapprox;'		=>	"\x{2A85}",
    '&lessdot;'			=>	"\x{22D6}",
    '&lesseqgtr;'		=>	"\x{22DA}",
    '&lesseqqgtr;'		=>	"\x{2A8B}",
    '&lessgtr;'			=>	"\x{2276}",
    '&lesssim;'			=>	"\x{2272}",
    '&lfisht;'			=>	"\x{297C}",
    '&lfloor;'			=>	"\x{230A}",
    '&lg;'			=>	"\x{2276}",
    '&lgE;'			=>	"\x{2A91}",
    '&lgr;'			=>	"\x{03BB}",
    '&lgr;'			=>	"\x{03BB}",
    '&lhard;'			=>	"\x{21BD}",
    '&lharu;'			=>	"\x{21BC}",
    '&lharul;'			=>	"\x{296A}",
    '&lhblk;'			=>	"\x{2584}",
    '&ljcy;'			=>	"\x{0459}",
    '&ll;'			=>	"\x{226A}",
    '&llarr;'			=>	"\x{21C7}",
    '&llbar;'			=>	"\x{019A}\x{019A}",
    '&llcorner;'		=>	"\x{231E}",
    '&llhard;'			=>	"\x{296B}",
    '&llslash;'			=>	"\x{0142}\x{0142}",
    '&lltri;'			=>	"\x{25FA}",
    '&lmidot;'			=>	"\x{0140}",
    '&lmoust;'			=>	"\x{23B0}",
    '&lmoustache;'		=>	"\x{23B0}",
    '&lnE;'			=>	"\x{2268}",
    '&lnap;'			=>	"\x{2A89}",
    '&lnapprox;'		=>	"\x{2A89}",
    '&lne;'			=>	"\x{2A87}",
    '&lneq;'			=>	"\x{2A87}",
    '&lneqq;'			=>	"\x{2268}",
    '&lnsim;'			=>	"\x{22E6}",
    '&loang;'			=>	"\x{3018}",
    '&loarr;'			=>	"\x{21FD}",
    '&lobrk;'			=>	"\x{301A}",
    '&long;'			=>	"\x{00AF}",
    '&long-s;'			=>	"\x{017F}",
    '&longleftarrow;'		=>	"\x{27F5}",
    '&longleftrightarrow;'	=>	"\x{27F7}",
    '&longmapsto;'		=>	"\x{27FC}",
    '&longrightarrow;'		=>	"\x{27F6}",
    '&looparrowleft;'		=>	"\x{21AB}",
    '&looparrowright;'		=>	"\x{21AC}",
    '&lopar;'			=>	"\x{2985}",
    '&loplus;'			=>	"\x{2A2D}",
    '&lotimes;'			=>	"\x{2A34}",
    '&lowast;'			=>	"\x{2217}",
    '&lowbar;'			=>	"\x{005F}",
    '&loz;'			=>	"\x{25CA}",
    '&lozenge;'			=>	"\x{25CA}",
    '&lozf;'			=>	"\x{29EB}",
    '&lpar;'			=>	"\x{0028}",
    '&lparlt;'			=>	"\x{2993}",
    '&lrarr;'			=>	"\x{21C6}",
    '&lrcorner;'		=>	"\x{231F}",
    '&lrhar;'			=>	"\x{21CB}",
    '&lrhard;'			=>	"\x{296D}",
    '&lrtri;'			=>	"\x{22BF}",
    '&lsh;'			=>	"\x{21B0}",
    '&lsim;'			=>	"\x{2272}",
    '&lsime;'			=>	"\x{2A8D}",
    '&lsimg;'			=>	"\x{2A8F}",
    '&lslash;'			=>	"\x{0142}",
    '&lsqb;'			=>	"\x{005B}",
    '&lsquo;'			=>	"\x{2018}",
    '&lsquor;'			=>	"\x{201A}",
    '&lstrok;'			=>	"\x{0142}",
    '&lt;'			=>	"\x{003C}",
    '&ltcc;'			=>	"\x{2AA6}",
    '&ltcir;'			=>	"\x{2A79}",
    '&ltdot;'			=>	"\x{22D6}",
    '&lthree;'			=>	"\x{22CB}",
    '&ltimes;'			=>	"\x{22C9}",
    '&ltlarr;'			=>	"\x{2976}",
    '&ltquest;'			=>	"\x{2A7B}",
    '&ltrPar;'			=>	"\x{2996}",
    '&ltri;'			=>	"\x{25C3}",
    '&ltrie;'			=>	"\x{22B4}",
    '&ltrif;'			=>	"\x{25C2}",
    '&lurdshar;'		=>	"\x{294A}",
    '&luruhar;'			=>	"\x{2966}",
    '&lvertneqq;'		=>	"\x{2268}",
    '&lvnE;'			=>	"\x{2268}",
    '&mDDot;'			=>	"\x{223A}",
    '&macr;'			=>	"\x{00AF}",
    '&male;'			=>	"\x{2642}",
    '&malt;'			=>	"\x{2720}",
    '&maltese;'			=>	"\x{2720}",
    '&map;'			=>	"\x{21A6}",
    '&mapsto;'			=>	"\x{21A6}",
    '&mapstodown;'		=>	"\x{21A7}",
    '&mapstoleft;'		=>	"\x{21A4}",
    '&mapstoup;'		=>	"\x{21A5}",
    '&marker;'			=>	"\x{25AE}",
    '&mbar;'			=>	"\x{006D}\x{0304}",
    '&mcomma;'			=>	"\x{2A29}",
    '&mcy;'			=>	"\x{043C}",
    '&mdash;'			=>	"\x{2014}",
    '&measuredangle;'		=>	"\x{2221}",
    '&meper;'			=>	"\x{002E}\x{0309}",
    '&mgr;'			=>	"\x{03BC}",
    '&mgr;'			=>	"\x{03BC}",
    '&mho;'			=>	"\x{2127}",
    '&micro;'			=>	"\x{00B5}",
    '&mid;'			=>	"\x{2223}",
    '&midast;'			=>	"\x{002A}",
    '&midcir;'			=>	"\x{2AF0}",
    '&middot;'			=>	"\x{00B7}",
    '&minus;'			=>	"\x{2212}",
    '&minusb;'			=>	"\x{229F}",
    '&minusd;'			=>	"\x{2238}",
    '&minusdu;'			=>	"\x{2A2A}",
    '&mlcp;'			=>	"\x{2ADB}",
    '&mldr;'			=>	"\x{2026}",
    '&mllhring;'		=>	"\x{02BF}",
    '&mmacr;'			=>	"\x{006D}\x{0304}",
    '&mnplus;'			=>	"\x{2213}",
    '&models;'			=>	"\x{22A7}",
    '&mp;'			=>	"\x{2213}",
    '&mstpos;'			=>	"\x{223E}",
    '&mtail;'			=>	"\x{006D}\x{031B}",
    '&mtilde;'			=>	"\x{006D}\x{0303}",
    '&mu;'			=>	"\x{03BC}",
    '&multimap;'		=>	"\x{22B8}",
    '&mumap;'			=>	"\x{22B8}",
    '&nGg;'			=>	"\x{22D9}",
    '&nGt;'			=>	"\x{226B}",
    '&nGtv;'			=>	"\x{226B}",
    '&nLeftarrow;'		=>	"\x{21CD}",
    '&nLeftrightarrow;'		=>	"\x{21CE}",
    '&nLl;'			=>	"\x{22D8}",
    '&nLt;'			=>	"\x{226A}",
    '&nLtv;'			=>	"\x{226A}",
    '&nRightarrow;'		=>	"\x{21CF}",
    '&nVDash;'			=>	"\x{22AF}",
    '&nVdash;'			=>	"\x{22AE}",
    '&nabla;'			=>	"\x{2207}",
    '&nacute;'			=>	"\x{0144}",
    '&nang;'			=>	"\x{2220}",
    '&nap;'			=>	"\x{2249}",
    '&napE;'			=>	"\x{2A70}",
    '&napid;'			=>	"\x{224B}",
    '&napos;'			=>	"\x{0149}",
    '&napprox;'			=>	"\x{2249}",
    '&natur;'			=>	"\x{266E}",
    '&natural;'			=>	"\x{266E}",
    '&naturals;'		=>	"\x{2115}",
    '&naugr;'			=>	"\x{03DB}",
    '&nbar;'			=>	"\x{006E}\x{0304}",
    '&nbsp;'			=>	"\x{00A0}",
    '&nbump;'			=>	"\x{224E}",
    '&nbumpe;'			=>	"\x{224F}",
    '&ncap;'			=>	"\x{2A43}",
    '&ncaron;'			=>	"\x{0148}",
    '&ncedil;'			=>	"\x{0146}",
    '&ncirc;'			=>	"\x{006E}\x{0302}",
    '&ncong;'			=>	"\x{2247}",
    '&ncongdot;'		=>	"\x{2A6D}",
    '&ncup;'			=>	"\x{2A42}",
    '&ncy;'			=>	"\x{043D}",
    '&ndash;'			=>	"\x{2013}",
    '&ne;'			=>	"\x{2260}",
    '&neArr;'			=>	"\x{21D7}",
    '&nearhk;'			=>	"\x{2924}",
    '&nearr;'			=>	"\x{2197}",
    '&nearrow;'			=>	"\x{2197}",
    '&nedot;'			=>	"\x{2250}",
    '&nequiv;'			=>	"\x{2262}",
    '&nesear;'			=>	"\x{2928}",
    '&nesim;'			=>	"\x{2242}",
    '&nexist;'			=>	"\x{2204}",
    '&nexists;'			=>	"\x{2204}",
    '&ngE;'			=>	"\x{2267}",
    '&nge;'			=>	"\x{2271}",
    '&ngeq;'			=>	"\x{2271}",
    '&ngeqq;'			=>	"\x{2267}",
    '&ngeqslant;'		=>	"\x{2A7E}",
    '&nges;'			=>	"\x{2A7E}",
    '&ngr;'			=>	"\x{03BD}",
    '&ngr;'			=>	"\x{03BD}",
    '&ngsim;'			=>	"\x{2275}",
    '&ngt;'			=>	"\x{226F}",
    '&ngtr;'			=>	"\x{226F}",
    '&nhArr;'			=>	"\x{21CE}",
    '&nharr;'			=>	"\x{21AE}",
    '&nhpar;'			=>	"\x{2AF2}",
    '&ni;'			=>	"\x{220B}",
    '&nis;'			=>	"\x{22FC}",
    '&nisd;'			=>	"\x{22FA}",
    '&niv;'			=>	"\x{220B}",
    '&njcy;'			=>	"\x{045A}",
    '&nlArr;'			=>	"\x{21CD}",
    '&nlE;'			=>	"\x{2266}",
    '&nlarr;'			=>	"\x{219A}",
    '&nldr;'			=>	"\x{2025}",
    '&nle;'			=>	"\x{2270}",
    '&nleftarrow;'		=>	"\x{219A}",
    '&nleftrightarrow;'		=>	"\x{21AE}",
    '&nleq;'			=>	"\x{2270}",
    '&nleqq;'			=>	"\x{2266}",
    '&nleqslant;'		=>	"\x{2A7D}",
    '&nles;'			=>	"\x{2A7D}",
    '&nless;'			=>	"\x{226E}",
    '&nlsim;'			=>	"\x{2274}",
    '&nlt;'			=>	"\x{226E}",
    '&nltri;'			=>	"\x{22EA}",
    '&nltrie;'			=>	"\x{22EC}",
    '&nmacr;'			=>	"\x{006E}\x{0304}",
    '&nmid;'			=>	"\x{2224}",
    '&not;'			=>	"\x{00AC}",
    '&notin;'			=>	"\x{2209}",
    '&notinE;'			=>	"\x{22F9}",
    '&notindot;'		=>	"\x{22F5}",
    '&notinva;'			=>	"\x{2209}",
    '&notinvb;'			=>	"\x{22F7}",
    '&notinvc;'			=>	"\x{22F6}",
    '&notni;'			=>	"\x{220C}",
    '&notniva;'			=>	"\x{220C}",
    '&notnivb;'			=>	"\x{22FE}",
    '&notnivc;'			=>	"\x{22FD}",
    '&npar;'			=>	"\x{2226}",
    '&nparallel;'		=>	"\x{2226}",
    '&nparsl;'			=>	"\x{2AFD}",
    '&npart;'			=>	"\x{2202}",
    '&npolint;'			=>	"\x{2A14}",
    '&npr;'			=>	"\x{2280}",
    '&nprcue;'			=>	"\x{22E0}",
    '&npre;'			=>	"\x{2AAF}",
    '&nprec;'			=>	"\x{2280}",
    '&npreceq;'			=>	"\x{2AAF}",
    '&nrArr;'			=>	"\x{21CF}",
    '&nrarr;'			=>	"\x{219B}",
    '&nrarrc;'			=>	"\x{2933}",
    '&nrarrw;'			=>	"\x{219D}",
    '&nrightarrow;'		=>	"\x{219B}",
    '&nrtri;'			=>	"\x{22EB}",
    '&nrtrie;'			=>	"\x{22ED}",
    '&nsc;'			=>	"\x{2281}",
    '&nsccue;'			=>	"\x{22E1}",
    '&nsce;'			=>	"\x{2AB0}",
    '&nshortmid;'		=>	"\x{2224}",
    '&nshortparallel;'		=>	"\x{2226}",
    '&nsim;'			=>	"\x{2241}",
    '&nsime;'			=>	"\x{2244}",
    '&nsimeq;'			=>	"\x{2244}",
    '&nsmid;'			=>	"\x{2224}",
    '&nspar;'			=>	"\x{2226}",
    '&nsqsube;'			=>	"\x{22E2}",
    '&nsqsupe;'			=>	"\x{22E3}",
    '&nsub;'			=>	"\x{2284}",
    '&nsubE;'			=>	"\x{2AC5}",
    '&nsube;'			=>	"\x{2288}",
    '&nsubset;'			=>	"\x{2282}",
    '&nsubseteq;'		=>	"\x{2288}",
    '&nsubseteqq;'		=>	"\x{2AC5}",
    '&nsucc;'			=>	"\x{2281}",
    '&nsucceq;'			=>	"\x{2AB0}",
    '&nsup;'			=>	"\x{2285}",
    '&nsupE;'			=>	"\x{2AC6}",
    '&nsupe;'			=>	"\x{2289}",
    '&nsupset;'			=>	"\x{2283}",
    '&nsupseteq;'		=>	"\x{2289}",
    '&nsupseteqq;'		=>	"\x{2AC6}",
    '&ntail;'			=>	"\x{006E}\x{031B}",
    '&ntgl;'			=>	"\x{2279}",
    '&ntilde;'			=>	"\x{00F1}",
    '&ntlg;'			=>	"\x{2278}",
    '&ntriangleleft;'		=>	"\x{22EA}",
    '&ntrianglelefteq;'		=>	"\x{22EC}",
    '&ntriangleright;'		=>	"\x{22EB}",
    '&ntrianglerighteq;'	=>	"\x{22ED}",
    '&nu;'			=>	"\x{03BD}",
    '&num;'			=>	"\x{0023}",
    '&numero;'			=>	"\x{2116}",
    '&numsp;'			=>	"\x{2007}",
    '&nvDash;'			=>	"\x{22AD}",
    '&nvHarr;'			=>	"\x{2904}",
    '&nvap;'			=>	"\x{224D}",
    '&nvdash;'			=>	"\x{22AC}",
    '&nvge;'			=>	"\x{2265}",
    '&nvgt;'			=>	"\x{003E}",
    '&nvinfin;'			=>	"\x{29DE}",
    '&nvlArr;'			=>	"\x{2902}",
    '&nvle;'			=>	"\x{2264}",
    '&nvlt;'			=>	"\x{003C}",
    '&nvltrie;'			=>	"\x{22B4}",
    '&nvrArr;'			=>	"\x{2903}",
    '&nvrtrie;'			=>	"\x{22B5}",
    '&nvsim;'			=>	"\x{223C}",
    '&nwArr;'			=>	"\x{21D6}",
    '&nwarhk;'			=>	"\x{2923}",
    '&nwarr;'			=>	"\x{2196}",
    '&nwarrow;'			=>	"\x{2196}",
    '&nwnear;'			=>	"\x{2927}",
    '&oS;'			=>	"\x{24C8}",
    '&oacgr;'			=>	"\x{03CC}",
    '&oacgr;'			=>	"\x{1F79}",
    '&oacugr;'			=>	"\x{1F79}",
    '&oacute;'			=>	"\x{00F3}",
    '&oast;'			=>	"\x{229B}",
    '&obar;'			=>	"\x{014D}",
    '&obreve;'			=>	"\x{006F}\x{0306}",
    '&ocedil;'			=>	"\x{6F}\x{327}",
    '&ocir;'			=>	"\x{229A}",
    '&ocirc;'			=>	"\x{00F4}",
    '&ocirgr;'			=>	"\x{3BF}\x{1FC0}",
    '&ocy;'			=>	"\x{043E}",
    '&odash;'			=>	"\x{229D}",
    '&odblac;'			=>	"\x{0151}",
    '&odiv;'			=>	"\x{2A38}",
    '&odot;'			=>	"\x{2299}",
    '&odsold;'			=>	"\x{29BC}",
    '&oelig;'			=>	"\x{0153}",
    '&ofcir;'			=>	"\x{29BF}",
    '&ogr;'			=>	"\x{03BF}",
    '&ogr;'			=>	"\x{03BF}",
    '&ogragr;'			=>	"\x{1F78}",
    '&ograve;'			=>	"\x{00F2}",
    '&ogt;'			=>	"\x{29C1}",
    '&ogvgr;'			=>	"\x{1F78}",
    '&ohacgr;'			=>	"\x{03CE}",
    '&ohacgr;'			=>	"\x{1F7D}",
    '&ohacugr;'			=>	"\x{1F7D}",
    '&ohaigr;'			=>	"\x{1FF4}",
    '&ohbar;'			=>	"\x{29B5}",
    '&ohcigr;'			=>	"\x{1FF7}",
    '&ohcirgr;'			=>	"\x{1FF6}",
    '&ohgigr;'			=>	"\x{1FF2}",
    '&ohgr;'			=>	"\x{03C9}",
    '&ohgr;'			=>	"\x{03C9}",
    '&ohgragr;'			=>	"\x{1F7C}",
    '&ohgvgr;'			=>	"\x{1F7C}",
    '&ohigr;'			=>	"\x{1FF3}",
    '&ohiotgr;'			=>	"\x{1FF3}",
    '&ohm;'			=>	"\x{2126}",
    '&ohragr;'			=>	"\x{1F65}",
    '&ohraigr;'			=>	"\x{1FA5}",
    '&ohrcgr;'			=>	"\x{1F67}",
    '&ohrcigr;'			=>	"\x{1FA7}",
    '&ohrggr;'			=>	"\x{1F63}",
    '&ohrgigr;'			=>	"\x{1FA3}",
    '&ohrigr;'			=>	"\x{1FA1}",
    '&ohrougr;'			=>	"\x{1F61}",
    '&ohsagr;'			=>	"\x{1F64}",
    '&ohsaigr;'			=>	"\x{1FA4}",
    '&ohscgr;'			=>	"\x{1F66}",
    '&ohscigr;'			=>	"\x{1FA6}",
    '&ohsggr;'			=>	"\x{1F62}",
    '&ohsgigr;'			=>	"\x{1FA2}",
    '&ohsigr;'			=>	"\x{1FA0}",
    '&ohsmogr;'			=>	"\x{1F60}",
    '&ohtigr;'			=>	"\x{1FF6}",
    '&oint;'			=>	"\x{222E}",
    '&olarr;'			=>	"\x{21BA}",
    '&olcir;'			=>	"\x{29BE}",
    '&olcross;'			=>	"\x{29BB}",
    '&olt;'			=>	"\x{29C0}",
    '&omacr;'			=>	"\x{014D}",
    '&omega;'			=>	"\x{03C9}",
    '&omid;'			=>	"\x{29B6}",
    '&ominus;'			=>	"\x{2296}",
    '&oogon;'			=>	"\x{01EB}",
    '&opar;'			=>	"\x{29B7}",
    '&operp;'			=>	"\x{29B9}",
    '&oplus;'			=>	"\x{2295}",
    '&or;'			=>	"\x{2228}",
    '&oragr;'			=>	"\x{1F45}",
    '&orarr;'			=>	"\x{21BB}",
    '&ord;'			=>	"\x{2A5D}",
    '&order;'			=>	"\x{2134}",
    '&orderof;'			=>	"\x{2134}",
    '&ordf;'			=>	"\x{00AA}",
    '&ordm;'			=>	"\x{00BA}",
    '&orggr;'			=>	"\x{1F43}",
    '&origof;'			=>	"\x{22B6}",
    '&oring;'			=>	"\x{006F}\x{030A}",
    '&oror;'			=>	"\x{2A56}",
    '&orougr;'			=>	"\x{1F41}",
    '&orslope;'			=>	"\x{2A57}",
    '&orv;'			=>	"\x{2A5B}",
    '&osagr;'			=>	"\x{1F44}",
    '&osggr;'			=>	"\x{1F42}",
    '&oshort;'			=>	"\x{006F}\x{0306}",
    '&oslash;'			=>	"\x{00F8}",
    '&osmogr;'			=>	"\x{1F40}",
    '&osol;'			=>	"\x{2298}",
    '&otail;'			=>	"\x{006F}\x{031B}",
    '&otigr;'			=>	"\x{03BF}\x{0342}",
    '&otilde;'			=>	"\x{00F5}",
    '&otimes;'			=>	"\x{2297}",
    '&otimesas;'		=>	"\x{2A36}",
    '&ouml;'			=>	"\x{00F6}",
    '&ovbar;'			=>	"\x{233D}",
    '&pacute;'			=>	"\x{0070}\x{0301}",
    '&par;'			=>	"\x{2225}",
    '&para;'			=>	"\x{00B6}",
    '&parallel;'		=>	"\x{2225}",
    '&parsim;'			=>	"\x{2AF3}",
    '&parsl;'			=>	"\x{2AFD}",
    '&part;'			=>	"\x{2202}",
    '&pbar;'			=>	"\x{0070}\x{0304}",
    '&pcy;'			=>	"\x{043F}",
    '&percnt;'			=>	"\x{0025}",
    '&period;'			=>	"\x{002E}",
    '&permil;'			=>	"\x{2030}",
    '&perp;'			=>	"\x{22A5}",
    '&pertenk;'			=>	"\x{2031}",
    '&pgr;'			=>	"\x{03C0}",
    '&pgr;'			=>	"\x{03C0}",
    '&phgr;'			=>	"\x{03C6}",
    '&phi;'			=>	"\x{03D5}",
    '&phiv;'			=>	"\x{03C6}",
    '&phmmat;'			=>	"\x{2133}",
    '&phone;'			=>	"\x{260E}",
    '&pi;'			=>	"\x{03C0}",
    '&pitchfork;'		=>	"\x{22D4}",
    '&piv;'			=>	"\x{03D6}",
    '&planck;'			=>	"\x{210F}",
    '&planckh;'			=>	"\x{210E}",
    '&plankv;'			=>	"\x{210F}",
    '&plus;'			=>	"\x{002B}",
    '&plusacir;'		=>	"\x{2A23}",
    '&plusb;'			=>	"\x{229E}",
    '&pluscir;'			=>	"\x{2A22}",
    '&plusdo;'			=>	"\x{2214}",
    '&plusdu;'			=>	"\x{2A25}",
    '&pluse;'			=>	"\x{2A72}",
    '&plusmn;'			=>	"\x{00B1}",
    '&plussim;'			=>	"\x{2A26}",
    '&plustwo;'			=>	"\x{2A27}",
    '&pm;'			=>	"\x{00B1}",
    '&pmacr;'			=>	"\x{0070}\x{0304}",
    '&point;'			=>	"\x{B7}",
    '&pointint;'		=>	"\x{2A15}",
    '&pound;'			=>	"\x{00A3}",
    '&pr;'			=>	"\x{227A}",
    '&prE;'			=>	"\x{2AB3}",
    '&prap;'			=>	"\x{2AB7}",
    '&prcue;'			=>	"\x{227C}",
    '&pre;'			=>	"\x{2AAF}",
    '&prec;'			=>	"\x{227A}",
    '&precapprox;'		=>	"\x{2AB7}",
    '&preccurlyeq;'		=>	"\x{227C}",
    '&preceq;'			=>	"\x{2AAF}",
    '&precnapprox;'		=>	"\x{2AB9}",
    '&precneqq;'		=>	"\x{2AB5}",
    '&precnsim;'		=>	"\x{22E8}",
    '&precsim;'			=>	"\x{227E}",
    '&prime;'			=>	"\x{2032}",
    '&primes;'			=>	"\x{2119}",
    '&prnE;'			=>	"\x{2AB5}",
    '&prnap;'			=>	"\x{2AB9}",
    '&prnsim;'			=>	"\x{22E8}",
    '&prod;'			=>	"\x{220F}",
    '&profalar;'		=>	"\x{232E}",
    '&profline;'		=>	"\x{2312}",
    '&profsurf;'		=>	"\x{2313}",
    '&prop;'			=>	"\x{221D}",
    '&propto;'			=>	"\x{221D}",
    '&prsim;'			=>	"\x{227E}",
    '&prurel;'			=>	"\x{22B0}",
    '&psgr;'			=>	"\x{03C8}",
    '&psi;'			=>	"\x{03C8}",
    '&ptail;'			=>	"\x{0070}\x{031B}",
    '&puncsp;'			=>	"\x{2008}",
    '&qacute;'			=>	"\x{0071}\x{0301}",
    '&qbar;'			=>	"\x{0071}\x{0304}",
    '&qbardash;'		=>	"\x{0071}\x{0320}\x{0304}",
    '&qdash;'			=>	"\x{0071}\x{0320}",
    '&qint;'			=>	"\x{2A0C}",
    '&qprime;'			=>	"\x{2057}",
    '&quaternions;'		=>	"\x{210D}",
    '&quatint;'			=>	"\x{2A16}",
    '&quest;'			=>	"\x{003F}",
    '&questeq;'			=>	"\x{225F}",
    '&quot;'			=>	"\x{0022}",
    '&rAarr;'			=>	"\x{21DB}",
    '&rArr;'			=>	"\x{21D2}",
    '&rAtail;'			=>	"\x{291C}",
    '&rBarr;'			=>	"\x{290F}",
    '&rHar;'			=>	"\x{2964}",
    '&rabr;'			=>	"\x{3009}",
    '&race;'			=>	"\x{29DA}",
    '&racute;'			=>	"\x{0155}",
    '&radic;'			=>	"\x{221A}",
    '&raemptyv;'		=>	"\x{29B3}",
    '&ragr;'			=>	"\x{1FDE}",
    '&rang;'			=>	"\x{232A}",
    '&rangd;'			=>	"\x{2992}",
    '&range;'			=>	"\x{29A5}",
    '&rangle;'			=>	"\x{232A}",
    '&raquo;'			=>	"\x{00BB}",
    '&rarr;'			=>	"\x{2192}",
    '&rarrap;'			=>	"\x{2975}",
    '&rarrb;'			=>	"\x{21E5}",
    '&rarrbfs;'			=>	"\x{2920}",
    '&rarrc;'			=>	"\x{2933}",
    '&rarrfs;'			=>	"\x{291E}",
    '&rarrhk;'			=>	"\x{21AA}",
    '&rarrlp;'			=>	"\x{21AC}",
    '&rarrpl;'			=>	"\x{2945}",
    '&rarrsim;'			=>	"\x{2974}",
    '&rarrtl;'			=>	"\x{21A3}",
    '&rarrw;'			=>	"\x{219D}",
    '&ratail;'			=>	"\x{291A}",
    '&ratio;'			=>	"\x{2236}",
    '&rationals;'		=>	"\x{211A}",
    '&rb;'			=>	"\x{02BD}",
    '&rbAacgr;'			=>	"\x{0391}",
    '&rbAgr;'			=>	"\x{0391}",
    '&rbAgvgr;'			=>	"\x{1F0B}",
    '&rbEEacgr;'		=>	"\x{0397}",
    '&rbEEgr;'			=>	"\x{1F29}",
    '&rbEacgr;'			=>	"\x{1F1D}",
    '&rbEgr;'			=>	"\x{0395}",
    '&rbIgr;'			=>	"\x{1F39}",
    '&rbOHgr;'			=>	"\x{1F69}",
    '&rbOacgr;'			=>	"\x{1F4D}",
    '&rbOgr;'			=>	"\x{1F49}",
    '&rbOgvgr;'			=>	"\x{039F}",
    '&rbRgr;'			=>	"\x{1FEC}",
    '&rbUacgr;'			=>	"\x{1F5D}",
    '&rbUgr;'			=>	"\x{03A5}",
    '&rbaacgr;'			=>	"\x{1F05}",
    '&rbagr;'			=>	"\x{1F01}",
    '&rbagvgr;'			=>	"\x{1F03}",
    '&rbar;'			=>	"\x{0072}\x{0304}",
    '&rbarr;'			=>	"\x{290D}",
    '&rbbrk;'			=>	"\x{3015}",
    '&rbeacgr;'			=>	"\x{1F15}",
    '&rbeeacgr;'		=>	"\x{1F25}",
    '&rbeegr;'			=>	"\x{1F29}",
    '&rbeegvgr;'		=>	"\x{1F23}",
    '&rbeetigr;'		=>	"\x{1F27}",
    '&rbegr;'			=>	"\x{1F11}",
    '&rbegvgr;'			=>	"\x{1F13}",
    '&rbiacgr;'			=>	"\x{1F35}",
    '&rbigr;'			=>	"\x{1F39}",
    '&rbigvgr;'			=>	"\x{1F33}",
    '&rbitigr;'			=>	"\x{1F37}",
    '&rboacgr;'			=>	"\x{1F4D}",
    '&rbogr;'			=>	"\x{1F41}",
    '&rbogvgr;'			=>	"\x{1F43}",
    '&rbohacgr;'		=>	"\x{1F65}",
    '&rbohgr;'			=>	"\x{1F61}",
    '&rbohtigr;'		=>	"\x{1F67}",
    '&rbotigr;'			=>	"\x{1F41}\x{0342}",
    '&rbrace;'			=>	"\x{007D}",
    '&rbrack;'			=>	"\x{005D}",
    '&rbrgr;'			=>	"\x{1FE5}",
    '&rbrke;'			=>	"\x{298C}",
    '&rbrksld;'			=>	"\x{298E}",
    '&rbrkslu;'			=>	"\x{2990}",
    '&rbuacgr;'			=>	"\x{1F55}",
    '&rbugr;'			=>	"\x{1F51}",
    '&rbugvgr;'			=>	"\x{1F53}",
    '&rbutigr;'			=>	"\x{1F57}",
    '&rcaron;'			=>	"\x{0159}",
    '&rcedil;'			=>	"\x{0157}",
    '&rceil;'			=>	"\x{2309}",
    '&rcgr;'			=>	"\x{1FDF}",
    '&rcub;'			=>	"\x{007D}",
    '&rcy;'			=>	"\x{0440}",
    '&rdca;'			=>	"\x{2937}",
    '&rdldhar;'			=>	"\x{2969}",
    '&rdquo;'			=>	"\x{201D}",
    '&rdquor;'			=>	"\x{201D}",
    '&rdsh;'			=>	"\x{21B3}",
    '&real;'			=>	"\x{211C}",
    '&realine;'			=>	"\x{211B}",
    '&realpart;'		=>	"\x{211C}",
    '&reals;'			=>	"\x{211D}",
    '&rect;'			=>	"\x{25AD}",
    '&reg;'			=>	"\x{00AE}",
    '&rfisht;'			=>	"\x{297D}",
    '&rfloor;'			=>	"\x{230B}",
    '&rggr;'			=>	"\x{1FDD}",
    '&rgr;'			=>	"\x{03C1}",
    '&rgr;'			=>	"\x{03C1}",
    '&rhacek;'			=>	"\x{0159}",
    '&rhand;'			=>	"\x{261E}",
    '&rhard;'			=>	"\x{21C1}",
    '&rharu;'			=>	"\x{21C0}",
    '&rharul;'			=>	"\x{296C}",
    '&rho;'			=>	"\x{03C1}",
    '&rhov;'			=>	"\x{03F1}",
    '&rightarrow;'		=>	"\x{2192}",
    '&rightarrowtail;'		=>	"\x{21A3}",
    '&rightharpoondown;'	=>	"\x{21C1}",
    '&rightharpoonup;'		=>	"\x{21C0}",
    '&rightleftarrows;'		=>	"\x{21C4}",
    '&rightleftharpoons;'	=>	"\x{21CC}",
    '&rightrightarrows;'	=>	"\x{21C9}",
    '&rightsquigarrow;'		=>	"\x{219D}",
    '&rightthreetimes;'		=>	"\x{22CC}",
    '&rindx;'			=>	"\x{261E}",
    '&risingdotseq;'		=>	"\x{2253}",
    '&rlarr;'			=>	"\x{21C4}",
    '&rlhar;'			=>	"\x{21CC}",
    '&rmacr;'			=>	"\x{0072}\x{0304}",
    '&rmoust;'			=>	"\x{23B1}",
    '&rmoustache;'		=>	"\x{23B1}",
    '&rnmid;'			=>	"\x{2AEE}",
    '&roang;'			=>	"\x{3019}",
    '&roarr;'			=>	"\x{21FE}",
    '&robrk;'			=>	"\x{301B}",
    '&ropar;'			=>	"\x{2986}",
    '&roplus;'			=>	"\x{2A2E}",
    '&rotimes;'			=>	"\x{2A35}",
    '&rougr;'			=>	"\x{1FFE}",
    '&rpar;'			=>	"\x{0029}",
    '&rpargt;'			=>	"\x{2994}",
    '&rppolint;'		=>	"\x{2A12}",
    '&rrarr;'			=>	"\x{21C9}",
    '&rrougr;'			=>	"\x{1FE5}",
    '&rsh;'			=>	"\x{21B1}",
    '&rsmogr;'			=>	"\x{1FE4}",
    '&rsqb;'			=>	"\x{005D}",
    '&rsquo;'			=>	"\x{2019}",
    '&rsquor;'			=>	"\x{2019}",
    '&rtail;'			=>	"\x{0072}\x{031B}",
    '&rthree;'			=>	"\x{22CC}",
    '&rtimes;'			=>	"\x{22CA}",
    '&rtri;'			=>	"\x{25B9}",
    '&rtrie;'			=>	"\x{22B5}",
    '&rtrif;'			=>	"\x{25B8}",
    '&rtriltri;'		=>	"\x{29CE}",
    '&ruluhar;'			=>	"\x{2968}",
    '&rx;'			=>	"\x{211E}",
    '&sacute;'			=>	"\x{015B}",
    '&sagr;'			=>	"\x{1FCE}",
    '&samgr;'			=>	"\x{03E0}",
    '&sb;'			=>	"\x{02BC}",
    '&sbAacgr;'			=>	"\x{1F0C}",
    '&sbAgr;'			=>	"\x{1F08}",
    '&sbEEacgr;'		=>	"\x{1F2C}",
    '&sbEEgr;'			=>	"\x{1F28}",
    '&sbEacgr;'			=>	"\x{1F1C}",
    '&sbEgr;'			=>	"\x{1F18}",
    '&sbIacgr;'			=>	"\x{1F3C}",
    '&sbIgr;'			=>	"\x{1F38}",
    '&sbOHgr;'			=>	"\x{1F68}",
    '&sbOHgvgr;'		=>	"\x{1F6A}",
    '&sbOacgr;'			=>	"\x{1F4C}",
    '&sbOgr;'			=>	"\x{1F48}",
    '&sbOtigr;'			=>	"\x{1F48}\x{0342}",
    '&sbUgr;'			=>	"\x{02BC}\x{03A5}",
    '&sbaacgr;'			=>	"\x{1F04}",
    '&sbagr;'			=>	"\x{1F08}",
    '&sbagvgr;'			=>	"\x{1F02}",
    '&sbar;'			=>	"\x{0073}\x{0304}",
    '&sbatigr;'			=>	"\x{1F06}",
    '&sbeacgr;'			=>	"\x{1F1C}",
    '&sbeeacgr;'		=>	"\x{1F24}",
    '&sbeegr;'			=>	"\x{1F28}",
    '&sbeegvgr;'		=>	"\x{1F22}",
    '&sbeetigr;'		=>	"\x{1F26}",
    '&sbegr;'			=>	"\x{1F18}",
    '&sbetigr;'			=>	"\x{1F10}\x{0342}",
    '&sbiacgr;'			=>	"\x{1F34}",
    '&sbigr;'			=>	"\x{1F38}",
    '&sbitigr;'			=>	"\x{1F36}",
    '&sboacgr;'			=>	"\x{1F44}",
    '&sbogr;'			=>	"\x{1F40}",
    '&sbogvgr;'			=>	"\x{1F42}",
    '&sbohacgr;'		=>	"\x{1F64}",
    '&sbohgr;'			=>	"\x{1F68}",
    '&sbohtigr;'		=>	"\x{1F66}",
    '&sbreve;'			=>	"\x{0053}\x{0306}",
    '&sbrgr;'			=>	"\x{1FE4}",
    '&sbuacgr;'			=>	"\x{1F54}",
    '&sbugr;'			=>	"\x{1F50}",
    '&sbugvgr;'			=>	"\x{1F52}",
    '&sbutigr;'			=>	"\x{1F56}",
    '&sc;'			=>	"\x{227B}",
    '&scE;'			=>	"\x{2AB4}",
    '&scap;'			=>	"\x{2AB8}",
    '&scaron;'			=>	"\x{0161}",
    '&sccue;'			=>	"\x{227D}",
    '&sce;'			=>	"\x{2AB0}",
    '&scedil;'			=>	"\x{015F}",
    '&scgr;'			=>	"\x{1FCF}",
    '&scirc;'			=>	"\x{015D}",
    '&scnE;'			=>	"\x{2AB6}",
    '&scnap;'			=>	"\x{2ABA}",
    '&scnsim;'			=>	"\x{22E9}",
    '&scpolint;'		=>	"\x{2A13}",
    '&scsim;'			=>	"\x{227F}",
    '&scy;'			=>	"\x{0441}",
    '&sdgr;'			=>	"\x{1FEE}",
    '&sdot;'			=>	"\x{22C5}",
    '&sdotb;'			=>	"\x{22A1}",
    '&sdote;'			=>	"\x{2A66}",
    '&seArr;'			=>	"\x{21D8}",
    '&searhk;'			=>	"\x{2925}",
    '&searr;'			=>	"\x{2198}",
    '&searrow;'			=>	"\x{2198}",
    '&sect;'			=>	"\x{00A7}",
    '&semi;'			=>	"\x{003B}",
    '&semiup;'			=>	"\x{61B}",
    '&seswar;'			=>	"\x{2929}",
    '&setminus;'		=>	"\x{2216}",
    '&setmn;'			=>	"\x{2216}",
    '&sext;'			=>	"\x{2736}",
    '&sfgr;'			=>	"\x{03B6}",
    '&sfgr;'			=>	"\x{03C2}",
    '&sfrown;'			=>	"\x{2322}",
    '&sggr;'			=>	"\x{1FCD}",
    '&sgr;'			=>	"\x{03C3}",
    '&sgr;'			=>	"\x{03C3}",
    '&sgrave;'			=>	"\x{0073}\x{0300}",
    '&shacek;'			=>	"\x{0161}",
    '&sharp;'			=>	"\x{266F}",
    '&shchcy;'			=>	"\x{0449}",
    '&shcy;'			=>	"\x{0448}",
    '&short;'			=>	"\x{02D8}",
    '&shortmid;'		=>	"\x{2223}",
    '&shortparallel;'		=>	"\x{2225}",
    '&shy;'			=>	"\x{00AD}",
    '&sigma;'			=>	"\x{03C3}",
    '&sigmav;'			=>	"\x{03C2}",
    '&sim;'			=>	"\x{223C}",
    '&simdot;'			=>	"\x{2A6A}",
    '&sime;'			=>	"\x{2243}",
    '&simeq;'			=>	"\x{2243}",
    '&simg;'			=>	"\x{2A9E}",
    '&simgE;'			=>	"\x{2AA0}",
    '&siml;'			=>	"\x{2A9D}",
    '&simlE;'			=>	"\x{2A9F}",
    '&simne;'			=>	"\x{2246}",
    '&simplus;'			=>	"\x{2A24}",
    '&simrarr;'			=>	"\x{2972}",
    '&sklong;'			=>	"\x{017F}\x{006B}",
    '&slarr;'			=>	"\x{2190}",
    '&slgr;'			=>	"\x{03C2}",
    '&sllong;'			=>	"\x{017F}\x{006C}",
    '&slong;'			=>	"\x{017F}",
    '&slungr;'			=>	"\x{03C2}",
    '&smacr;'			=>	"\x{0073}\x{0304}",
    '&smallsetminus;'		=>	"\x{2216}",
    '&smashp;'			=>	"\x{2A33}",
    '&smeparsl;'		=>	"\x{29E4}",
    '&smid;'			=>	"\x{2223}",
    '&smile;'			=>	"\x{2323}",
    '&smogr;'			=>	"\x{1FBD}",
    '&smt;'			=>	"\x{2AAA}",
    '&smte;'			=>	"\x{2AAC}",
    '&smtes;'			=>	"\x{2AAC}",
    '&softcy;'			=>	"\x{044C}",
    '&sol;'			=>	"\x{002F}",
    '&solb;'			=>	"\x{29C4}",
    '&solbar;'			=>	"\x{233F}",
    '&spades;'			=>	"\x{2660}",
    '&spadesuit;'		=>	"\x{2660}",
    '&spar;'			=>	"\x{2225}",
    '&sqcap;'			=>	"\x{2293}",
    '&sqcaps;'			=>	"\x{2293}",
    '&sqcup;'			=>	"\x{2294}",
    '&sqcups;'			=>	"\x{2294}",
    '&sqroot;'			=>	"\x{221A}",
    '&sqsub;'			=>	"\x{228F}",
    '&sqsube;'			=>	"\x{2291}",
    '&sqsubset;'		=>	"\x{228F}",
    '&sqsubseteq;'		=>	"\x{2291}",
    '&sqsup;'			=>	"\x{2290}",
    '&sqsupe;'			=>	"\x{2292}",
    '&sqsupset;'		=>	"\x{2290}",
    '&sqsupseteq;'		=>	"\x{2292}",
    '&squ;'			=>	"\x{25A1}",
    '&square;'			=>	"\x{25A1}",
    '&squarf;'			=>	"\x{25AA}",
    '&squf;'			=>	"\x{25AA}",
    '&srarr;'			=>	"\x{2192}",
    '&ssetmn;'			=>	"\x{2216}",
    '&sslong;'			=>	"\x{017F}\x{017F}",
    '&ssmile;'			=>	"\x{2323}",
    '&sstarf;'			=>	"\x{22C6}",
    '&star;'			=>	"\x{2606}",
    '&starf;'			=>	"\x{2605}",
    '&stlong;'			=>	"\x{017F}\x{0074}",
    '&straightepsilon;'		=>	"\x{03B5}",
    '&straightphi;'		=>	"\x{03D5}",
    '&strns;'			=>	"\x{00AF}",
    '&sub;'			=>	"\x{2282}",
    '&subE;'			=>	"\x{2AC5}",
    '&subdot;'			=>	"\x{2ABD}",
    '&sube;'			=>	"\x{2286}",
    '&subedot;'			=>	"\x{2AC3}",
    '&submult;'			=>	"\x{2AC1}",
    '&subnE;'			=>	"\x{2ACB}",
    '&subne;'			=>	"\x{228A}",
    '&subplus;'			=>	"\x{2ABF}",
    '&subrarr;'			=>	"\x{2979}",
    '&subset;'			=>	"\x{2282}",
    '&subseteq;'		=>	"\x{2286}",
    '&subseteqq;'		=>	"\x{2AC5}",
    '&subsetneq;'		=>	"\x{228A}",
    '&subsetneqq;'		=>	"\x{2ACB}",
    '&subsim;'			=>	"\x{2AC7}",
    '&subsub;'			=>	"\x{2AD5}",
    '&subsup;'			=>	"\x{2AD3}",
    '&succ;'			=>	"\x{227B}",
    '&succapprox;'		=>	"\x{2AB8}",
    '&succcurlyeq;'		=>	"\x{227D}",
    '&succeq;'			=>	"\x{2AB0}",
    '&succnapprox;'		=>	"\x{2ABA}",
    '&succneqq;'		=>	"\x{2AB6}",
    '&succnsim;'		=>	"\x{22E9}",
    '&succsim;'			=>	"\x{227F}",
    '&sum;'			=>	"\x{2211}",
    '&sung;'			=>	"\x{266A}",
    '&sup;'			=>	"\x{2283}",
    '&sup1;'			=>	"\x{00B9}",
    '&sup2;'			=>	"\x{00B2}",
    '&sup3;'			=>	"\x{00B3}",
    '&supE;'			=>	"\x{2AC6}",
    '&supdot;'			=>	"\x{2ABE}",
    '&supdsub;'			=>	"\x{2AD8}",
    '&supe;'			=>	"\x{2287}",
    '&supedot;'			=>	"\x{2AC4}",
    '&super1;'			=>	"\x{B9}",
    '&super2;'			=>	"\x{B2}",
    '&super3;'			=>	"\x{B3}",
    '&super4;'			=>	"\x{2074}",
    '&super5;'			=>	"\x{2075}",
    '&suphsol;'			=>	"\x{2283}",
    '&suphsub;'			=>	"\x{2AD7}",
    '&suplarr;'			=>	"\x{297B}",
    '&supmult;'			=>	"\x{2AC2}",
    '&supnE;'			=>	"\x{2ACC}",
    '&supne;'			=>	"\x{228B}",
    '&supplus;'			=>	"\x{2AC0}",
    '&supset;'			=>	"\x{2283}",
    '&supseteq;'		=>	"\x{2287}",
    '&supseteqq;'		=>	"\x{2AC6}",
    '&supsetneq;'		=>	"\x{228B}",
    '&supsetneqq;'		=>	"\x{2ACC}",
    '&supsim;'			=>	"\x{2AC8}",
    '&supsub;'			=>	"\x{2AD4}",
    '&supsup;'			=>	"\x{2AD6}",
    '&swArr;'			=>	"\x{21D9}",
    '&swarhk;'			=>	"\x{2926}",
    '&swarr;'			=>	"\x{2199}",
    '&swarrow;'			=>	"\x{2199}",
    '&swnwar;'			=>	"\x{292A}",
    '&szlig;'			=>	"\x{00DF}",
    '&target;'			=>	"\x{2316}",
    '&tau;'			=>	"\x{03C4}",
    '&tbar;'			=>	"\x{0074}\x{0304}",
    '&tbrk;'			=>	"\x{23B4}",
    '&tcaron;'			=>	"\x{0165}",
    '&tcedil;'			=>	"\x{0163}",
    '&tcy;'			=>	"\x{0442}",
    '&tdot;'			=>	"\x{20DB}",
    '&telrec;'			=>	"\x{2315}",
    '&tgr;'			=>	"\x{03C4}",
    '&tgr;'			=>	"\x{03C4}",
    '&that;'			=>	"\x{00FE}\x{0331}",
    '&there4;'			=>	"\x{2234}",
    '&therefore;'		=>	"\x{2234}",
    '&theta;'			=>	"\x{03B8}",
    '&thetas;'			=>	"\x{03B8}",
    '&thetav;'			=>	"\x{03D1}",
    '&thetav;'			=>	"\x{03D1}",
    '&thgr;'			=>	"\x{03B8}",
    '&thgr;'			=>	"\x{03B8}",
    '&thickapprox;'		=>	"\x{2248}",
    '&thicksim;'		=>	"\x{223C}",
    '&thinsp;'			=>	"\x{2009}",
    '&thkap;'			=>	"\x{2248}",
    '&thksim;'			=>	"\x{223C}",
    '&thorn;'			=>	"\x{00FE}",
    '&times;'			=>	"\x{00D7}",
    '&timesb;'			=>	"\x{22A0}",
    '&timesbar;'		=>	"\x{2A31}",
    '&timesd;'			=>	"\x{2A30}",
    '&tint;'			=>	"\x{222D}",
    '&toea;'			=>	"\x{2928}",
    '&top;'			=>	"\x{22A4}",
    '&topbot;'			=>	"\x{2336}",
    '&topcir;'			=>	"\x{2AF1}",
    '&topfork;'			=>	"\x{2ADA}",
    '&tosa;'			=>	"\x{2929}",
    '&tprime;'			=>	"\x{2034}",
    '&trade;'			=>	"\x{2122}",
    '&triangle;'		=>	"\x{25B5}",
    '&triangledown;'		=>	"\x{25BF}",
    '&triangleleft;'		=>	"\x{25C3}",
    '&trianglelefteq;'		=>	"\x{22B4}",
    '&triangleq;'		=>	"\x{225C}",
    '&triangleright;'		=>	"\x{25B9}",
    '&trianglerighteq;'		=>	"\x{22B5}",
    '&tridot;'			=>	"\x{25EC}",
    '&trie;'			=>	"\x{225C}",
    '&triminus;'		=>	"\x{2A3A}",
    '&triplus;'			=>	"\x{2A39}",
    '&trisb;'			=>	"\x{29CD}",
    '&tritime;'			=>	"\x{2A3B}",
    '&trpezium;'		=>	"\x{FFFD}",
    '&tscy;'			=>	"\x{0446}",
    '&tshcy;'			=>	"\x{045B}",
    '&tstrok;'			=>	"\x{0167}",
    '&ttee;'			=>	"\x{0074}\x{0318}",
    '&twixt;'			=>	"\x{226C}",
    '&twoheadleftarrow;'	=>	"\x{219E}",
    '&twoheadrightarrow;'	=>	"\x{21A0}",
    '&uArr;'			=>	"\x{21D1}",
    '&uHar;'			=>	"\x{2963}",
    '&uacgr;'			=>	"\x{03CD}",
    '&uacgr;'			=>	"\x{1F7B}",
    '&uacugr;'			=>	"\x{1F7B}",
    '&uacute;'			=>	"\x{00FA}",
    '&uadgr;'			=>	"\x{1FE3}",
    '&uarr;'			=>	"\x{2191}",
    '&ubar;'			=>	"\x{016B}",
    '&ubrcy;'			=>	"\x{045E}",
    '&ubreve;'			=>	"\x{016D}",
    '&ucdgr;'			=>	"\x{1F57}",
    '&ucirc;'			=>	"\x{00FB}",
    '&ucirgr;'			=>	"\x{1FE6}",
    '&ucy;'			=>	"\x{0443}",
    '&udarr;'			=>	"\x{21C5}",
    '&udblac;'			=>	"\x{0171}",
    '&udhar;'			=>	"\x{296E}",
    '&udiagr;'			=>	"\x{03B0}",
    '&udiagr;'			=>	"\x{03CB}",
    '&udigr;'			=>	"\x{03CB}",
    '&udigr;'			=>	"\x{03CB}",
    '&udot;'			=>	"\x{1EE5}",
    '&ufisht;'			=>	"\x{297E}",
    '&ugdgr;'			=>	"\x{1FE2}",
    '&ugr;'			=>	"\x{03C5}",
    '&ugr;'			=>	"\x{03C5}",
    '&ugragr;'			=>	"\x{1F7A}",
    '&ugrave;'			=>	"\x{00F9}",
    '&ugvgr;'			=>	"\x{1F7A}",
    '&uharl;'			=>	"\x{21BF}",
    '&uharr;'			=>	"\x{21BE}",
    '&uhblk;'			=>	"\x{2580}",
    '&ulcorn;'			=>	"\x{231C}",
    '&ulcorner;'		=>	"\x{231C}",
    '&ulcrop;'			=>	"\x{230F}",
    '&ultri;'			=>	"\x{25F8}",
    '&umacr;'			=>	"\x{016B}",
    '&uogon;'			=>	"\x{0173}",
    '&uparrow;'			=>	"\x{2191}",
    '&updownarrow;'		=>	"\x{2195}",
    '&upexcl;'			=>	"\x{A1}",
    '&upharpoonleft;'		=>	"\x{21BF}",
    '&upharpoonright;'		=>	"\x{21BE}",
    '&uplus;'			=>	"\x{228E}",
    '&upsi;'			=>	"\x{03C5}",
    '&upsilon;'			=>	"\x{03C5}",
    '&upuparrows;'		=>	"\x{21C8}",
    '&uragr;'			=>	"\x{1F55}",
    '&urcgr;'			=>	"\x{1F57}",
    '&urcorn;'			=>	"\x{231D}",
    '&urcorner;'		=>	"\x{231D}",
    '&urcrop;'			=>	"\x{230E}",
    '&urggr;'			=>	"\x{1F53}",
    '&uring;'			=>	"\x{016F}",
    '&urougr;'			=>	"\x{1F51}",
    '&urtri;'			=>	"\x{25F9}",
    '&usagr;'			=>	"\x{1F54}",
    '&uscgr;'			=>	"\x{1F56}",
    '&usggr;'			=>	"\x{1F52}",
    '&ushort;'			=>	"\x{016D}",
    '&usmogr;'			=>	"\x{1F50}",
    '&utail;'			=>	"\x{0075}\x{031B}",
    '&utdot;'			=>	"\x{22F0}",
    '&utigr;'			=>	"\x{1FE6}",
    '&utilde;'			=>	"\x{0169}",
    '&utri;'			=>	"\x{25B5}",
    '&utrif;'			=>	"\x{25B4}",
    '&uuarr;'			=>	"\x{21C8}",
    '&uuml;'			=>	"\x{00FC}",
    '&uwangle;'			=>	"\x{29A7}",
    '&vArr;'			=>	"\x{21D5}",
    '&vBar;'			=>	"\x{2AE8}",
    '&vBarv;'			=>	"\x{2AE9}",
    '&vDash;'			=>	"\x{22A8}",
    '&vangrt;'			=>	"\x{299C}",
    '&varepsilon;'		=>	"\x{025B}",
    '&varkappa;'		=>	"\x{03F0}",
    '&varnothing;'		=>	"\x{2205}",
    '&varphi;'			=>	"\x{03C6}",
    '&varpi;'			=>	"\x{03D6}",
    '&varpropto;'		=>	"\x{221D}",
    '&varr;'			=>	"\x{2195}",
    '&varrho;'			=>	"\x{03F1}",
    '&varsigma;'		=>	"\x{03C2}",
    '&varsubsetneq;'		=>	"\x{228A}",
    '&varsubsetneqq;'		=>	"\x{2ACB}",
    '&varsupsetneq;'		=>	"\x{228B}",
    '&varsupsetneqq;'		=>	"\x{2ACC}",
    '&vartheta;'		=>	"\x{03D1}",
    '&vartriangleleft;'		=>	"\x{22B2}",
    '&vartriangleright;'	=>	"\x{22B3}",
    '&vcy;'			=>	"\x{0432}",
    '&vdash;'			=>	"\x{22A2}",
    '&vee;'			=>	"\x{2228}",
    '&veebar;'			=>	"\x{22BB}",
    '&veeeq;'			=>	"\x{225A}",
    '&vellip;'			=>	"\x{22EE}",
    '&verbar;'			=>	"\x{007C}",
    '&vert;'			=>	"\x{007C}",
    '&vltri;'			=>	"\x{22B2}",
    '&vmacr;'			=>	"\x{0076}\x{0304}",
    '&vnsub;'			=>	"\x{2282}",
    '&vnsup;'			=>	"\x{2283}",
    '&vprop;'			=>	"\x{221D}",
    '&vrtri;'			=>	"\x{22B3}",
    '&vsubnE;'			=>	"\x{2ACB}",
    '&vsubne;'			=>	"\x{228A}",
    '&vsupnE;'			=>	"\x{2ACC}",
    '&vsupne;'			=>	"\x{228B}",
    '&vtilde;'			=>	"\x{1E7D}",
    '&vzigzag;'			=>	"\x{299A}",
    '&wbar;'			=>	"\x{0077}\x{0304}",
    '&wcirc;'			=>	"\x{0175}",
    '&wedbar;'			=>	"\x{2A5F}",
    '&wedge;'			=>	"\x{2227}",
    '&wedgeq;'			=>	"\x{2259}",
    '&weierp;'			=>	"\x{2118}",
    '&wmacr;'			=>	"\x{0077}\x{0304}",
    '&wp;'			=>	"\x{2118}",
    '&wr;'			=>	"\x{2240}",
    '&wreath;'			=>	"\x{2240}",
    '&wtail;'			=>	"\x{0077}\x{31B4}",
    '&wyn;'			=>	"\x{01BF}",
    '&xcap;'			=>	"\x{22C2}",
    '&xcirc;'			=>	"\x{25EF}",
    '&xcup;'			=>	"\x{22C3}",
    '&xdtri;'			=>	"\x{25BD}",
    '&xgr;'			=>	"\x{03BE}",
    '&xgr;'			=>	"\x{03BE}",
    '&xhArr;'			=>	"\x{27FA}",
    '&xharr;'			=>	"\x{27F7}",
    '&xi;'			=>	"\x{03BE}",
    '&xlArr;'			=>	"\x{27F8}",
    '&xlarr;'			=>	"\x{27F5}",
    '&xmap;'			=>	"\x{27FC}",
    '&xnis;'			=>	"\x{22FB}",
    '&xodot;'			=>	"\x{2A00}",
    '&xoplus;'			=>	"\x{2A01}",
    '&xotime;'			=>	"\x{2A02}",
    '&xrArr;'			=>	"\x{27F9}",
    '&xrarr;'			=>	"\x{27F6}",
    '&xsqcup;'			=>	"\x{2A06}",
    '&xuplus;'			=>	"\x{2A04}",
    '&xutri;'			=>	"\x{25B3}",
    '&xvee;'			=>	"\x{22C1}",
    '&xwedge;'			=>	"\x{22C0}",
    '&yacute;'			=>	"\x{00FD}",
    '&yacy;'			=>	"\x{044F}",
    '&ybar;'			=>	"\x{233}",
    '&ycirc;'			=>	"\x{0177}",
    '&ycy;'			=>	"\x{044B}",
    '&ydot;'			=>	"\x{1E8F}",
    '&yen;'			=>	"\x{00A5}",
    '&ygrave;'			=>	"\x{1EF3}",
    '&yicy;'			=>	"\x{0457}",
    '&ymacr;'			=>	"\x{0233}",
    '&yogh;'			=>	"\x{021D}",
    '&yshort;'			=>	"\x{0079}\x{0306}",
    '&ytilde;'			=>	"\x{1EF9}",
    '&yucy;'			=>	"\x{044E}",
    '&yuml;'			=>	"\x{00FF}",
    '&zacute;'			=>	"\x{017A}",
    '&zcaron;'			=>	"\x{017E}",
    '&zcy;'			=>	"\x{0437}",
    '&zdot;'			=>	"\x{017C}",
    '&zeetrf;'			=>	"\x{2128}",
    '&zeta;'			=>	"\x{03B6}",
    '&zgr;'			=>	"\x{03B6}",
    '&zhcy;'			=>	"\x{0436}",
    '&zigrarr;'			=>	"\x{21DD}",
);

sub toReplacement {
    my ($entity) = @_;

    # Skip the allowable entities.
    return $entity if ($allow{$entity});

    # was it a hex or decimal entity that should be one of the standard entities?
    my $replacement = $numeric{lc($entity)};

    # If it weren't, then see if it is a known entity
    if (!$replacement) {
        # See if it is a known character entity
        $replacement = $entities{$entity};
    }

    # If it weren't then see if it is a numeric entity
    if (!$replacement) {
        # Was it a hex or decimal numeric entity?
        if ($entity =~ /^\&#x([0-9a-f]+);$/io) {
            # it was hex
            $replacement = chr(hex($1));
        } elsif ($entity =~ /^\&#([0-9]+);$/o) {
            # it was decimal
            $replacement = chr($1);
        }
    }

    # return the replacement, if any
    # otherwise the origial
    $replacement || $entity;
}

1;
__END__

=head1 NAME

EntityReplacer - Perl extension for converting numeric and character entities to UTF-8.

=head1 SYNOPSIS

  use EntityReplacer;
  binmode(STDOUT, ":utf8");

  while (<>) {
    s/(\&#?[a-z0-9-]+;)/EntityReplacer::toReplacement($1)/geoi;
    print;
  }

=head1 DESCRIPTION

EntityReplacer the following:

=over 3

=item *
Maps numeric entites representing &, >, <, " and ' with their corresponding character entity.

=item *
Does not map character entities for &, >, <, " and '.

=item * Otherwise maps numeric and known character entities to utf-8.
The known entities are defined:
 ISOAMSA ISOAMSB ISOAMSC ISOAMSN ISOAMSO ISOAMSR ISOCYR1 ISOCYR2
 ISOGRK1 ISOGRK2 ISOGRK3 ISOGRK4 ISOLAT1 ISOLAT2 ISOMFRK ISONUM
 ISOPUB ISOTECH MMLALIAS MMLEXTRA

=back

=head2 EXPORT

None by default.

=head2 FUNCTIONS

toReplacement($entity)

Given an entity starting with & and ending with ; toReplacement($entity) will return a substitution for the entity or will return the entity if no replacement was found.

=head1 SEE ALSO

Website:
http://www.crosswire.org/~dmsmith/perl

ISO standards:
http://www.w3.org/TR/xml-entity-names

=head1 AUTHOR

DM Smith

For general inquiries, comments, suggestions, bug reports, etc. email:
sword-support@crosswire.org

=head1 COPYRIGHT AND LICENSE

 Licensed under the standard BSD license:

 Copyright (c) 2009 CrossWire Bible Society <http://www.crosswire.org/>
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are
 met:

=over 3

=item *
 Redistributions of source code must retain the above copyright
 notice, this list of conditions and the following disclaimer.

=item *
 Redistributions in binary form must reproduce the above copyright
 notice, this list of conditions and the following disclaimer in
 the documentation and/or other materials provided with the
 distribution.

=item *
 Neither the name of the CrossWire Bible Society nor the names of
 its contributors may be used to endorse or promote products
 derived from this software without specific prior written
 permission.

=back
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut
